# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.smooth_manifest_content_protection import SmoothManifestContentProtection
from bitmovin_api_sdk.encoding.manifests.smooth.contentprotection.smooth_manifest_content_protection_list_query_params import SmoothManifestContentProtectionListQueryParams


class ContentprotectionApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(ContentprotectionApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, manifest_id, smooth_manifest_content_protection, **kwargs):
        # type: (string_types, SmoothManifestContentProtection, dict) -> SmoothManifestContentProtection
        """Add Content Protection to Smooth Streaming

        :param manifest_id: Id of the Smooth Streaming manifest.
        :type manifest_id: string_types, required
        :param smooth_manifest_content_protection: The Content Protection to be added
        :type smooth_manifest_content_protection: SmoothManifestContentProtection, required
        :return: Content protection
        :rtype: SmoothManifestContentProtection
        """

        return self.api_client.post(
            '/encoding/manifests/smooth/{manifest_id}/contentprotection',
            smooth_manifest_content_protection,
            path_params={'manifest_id': manifest_id},
            type=SmoothManifestContentProtection,
            **kwargs
        )

    def delete(self, manifest_id, protection_id, **kwargs):
        # type: (string_types, string_types, dict) -> BitmovinResponse
        """Delete Content Protection of Smooth Streaming

        :param manifest_id: Id of the Smooth Streaming manifest.
        :type manifest_id: string_types, required
        :param protection_id: Id of the content protection.
        :type protection_id: string_types, required
        :return: Id of the content protection
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/manifests/smooth/{manifest_id}/contentprotection/{protection_id}',
            path_params={'manifest_id': manifest_id, 'protection_id': protection_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, manifest_id, protection_id, **kwargs):
        # type: (string_types, string_types, dict) -> SmoothManifestContentProtection
        """Content Protection of Smooth Streaming Representation Details

        :param manifest_id: Id of the Smooth Streaming manifest.
        :type manifest_id: string_types, required
        :param protection_id: Id of the content protection.
        :type protection_id: string_types, required
        :return: Content protection details
        :rtype: SmoothManifestContentProtection
        """

        return self.api_client.get(
            '/encoding/manifests/smooth/{manifest_id}/contentprotection/{protection_id}',
            path_params={'manifest_id': manifest_id, 'protection_id': protection_id},
            type=SmoothManifestContentProtection,
            **kwargs
        )

    def list(self, manifest_id, query_params=None, **kwargs):
        # type: (string_types, SmoothManifestContentProtectionListQueryParams, dict) -> SmoothManifestContentProtection
        """List Content Protection of Smooth Streaming

        :param manifest_id: Id of the Smooth Streaming manifest.
        :type manifest_id: string_types, required
        :param query_params: Query parameters
        :type query_params: SmoothManifestContentProtectionListQueryParams
        :return: Content protection results
        :rtype: SmoothManifestContentProtection
        """

        return self.api_client.get(
            '/encoding/manifests/smooth/{manifest_id}/contentprotection',
            path_params={'manifest_id': manifest_id},
            query_params=query_params,
            pagination_response=True,
            type=SmoothManifestContentProtection,
            **kwargs
        )



from bitmovin_api_sdk.encoding.inputs.redundant_rtmp.redundant_rtmp_api import RedundantRtmpApi
from bitmovin_api_sdk.encoding.inputs.redundant_rtmp.redundant_rtmp_input_list_query_params import RedundantRtmpInputListQueryParams



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.i_frame_playlist import IFramePlaylist
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.manifests.hls.streams.iframe.i_frame_playlist_list_query_params import IFramePlaylistListQueryParams


class IframeApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(IframeApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, manifest_id, stream_id, i_frame_playlist, **kwargs):
        # type: (string_types, string_types, IFramePlaylist, dict) -> IFramePlaylist
        """Add I-frame playlist to variant stream

        :param manifest_id: Id of the hls manifest.
        :type manifest_id: string_types, required
        :param stream_id: Id of the variant stream.
        :type stream_id: string_types, required
        :param i_frame_playlist: The I-frame playlist to be added
        :type i_frame_playlist: IFramePlaylist, required
        :return: Iframe-Playlist details
        :rtype: IFramePlaylist
        """

        return self.api_client.post(
            '/encoding/manifests/hls/{manifest_id}/streams/{stream_id}/iframe',
            i_frame_playlist,
            path_params={'manifest_id': manifest_id, 'stream_id': stream_id},
            type=IFramePlaylist,
            **kwargs
        )

    def delete(self, manifest_id, stream_id, iframe_id, **kwargs):
        # type: (string_types, string_types, string_types, dict) -> BitmovinResponse
        """Delete I-frame playlist

        :param manifest_id: Id of the hls manifest.
        :type manifest_id: string_types, required
        :param stream_id: Id of the variant stream.
        :type stream_id: string_types, required
        :param iframe_id: Id of the Iframe-Playlist.
        :type iframe_id: string_types, required
        :return: Id of the custom tag
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/manifests/hls/{manifest_id}/streams/{stream_id}/iframe/{iframe_id}',
            path_params={'manifest_id': manifest_id, 'stream_id': stream_id, 'iframe_id': iframe_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, manifest_id, stream_id, iframe_id, **kwargs):
        # type: (string_types, string_types, string_types, dict) -> IFramePlaylist
        """I-frame playlist Details

        :param manifest_id: Id of the hls manifest.
        :type manifest_id: string_types, required
        :param stream_id: Id of the variant stream.
        :type stream_id: string_types, required
        :param iframe_id: Id of the Iframe-Playlist.
        :type iframe_id: string_types, required
        :return: Custom tag details
        :rtype: IFramePlaylist
        """

        return self.api_client.get(
            '/encoding/manifests/hls/{manifest_id}/streams/{stream_id}/iframe/{iframe_id}',
            path_params={'manifest_id': manifest_id, 'stream_id': stream_id, 'iframe_id': iframe_id},
            type=IFramePlaylist,
            **kwargs
        )

    def list(self, manifest_id, stream_id, query_params=None, **kwargs):
        # type: (string_types, string_types, IFramePlaylistListQueryParams, dict) -> IFramePlaylist
        """List all I-frame playlists of a variant stream

        :param manifest_id: Id of the hls manifest.
        :type manifest_id: string_types, required
        :param stream_id: Id of the variant stream.
        :type stream_id: string_types, required
        :param query_params: Query parameters
        :type query_params: IFramePlaylistListQueryParams
        :return: Video media
        :rtype: IFramePlaylist
        """

        return self.api_client.get(
            '/encoding/manifests/hls/{manifest_id}/streams/{stream_id}/iframe',
            path_params={'manifest_id': manifest_id, 'stream_id': stream_id},
            query_params=query_params,
            pagination_response=True,
            type=IFramePlaylist,
            **kwargs
        )



from bitmovin_api_sdk.encoding.configurations.video.av1.av1_api import Av1Api
from bitmovin_api_sdk.encoding.configurations.video.av1.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.configurations.video.av1.av1_video_configuration_list_query_params import Av1VideoConfigurationListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class InputStreamType(Enum):
    INGEST = "INGEST"
    CONCATENATION = "CONCATENATION"
    TRIMMING_TIME_BASED = "TRIMMING_TIME_BASED"
    TRIMMING_TIME_CODE_TRACK = "TRIMMING_TIME_CODE_TRACK"
    TRIMMING_H264_PICTURE_TIMING = "TRIMMING_H264_PICTURE_TIMING"
    SIDECAR_DOLBY_VISION_METADATA = "SIDECAR_DOLBY_VISION_METADATA"
    AUDIO_MIX = "AUDIO_MIX"
    FILE = "FILE"
    CAPTION_CEA608 = "CAPTION_CEA608"
    CAPTION_CEA708 = "CAPTION_CEA708"
    DVB_SUBTITLE = "DVB_SUBTITLE"
    DVB_TELETEXT = "DVB_TELETEXT"
    DOLBY_ATMOS = "DOLBY_ATMOS"
    DOLBY_VISION = "DOLBY_VISION"



from bitmovin_api_sdk.encoding.inputs.aspera.aspera_api import AsperaApi
from bitmovin_api_sdk.encoding.inputs.aspera.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.inputs.aspera.aspera_input_list_query_params import AsperaInputListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class MuxingType(Enum):
    FMP4 = "FMP4"
    CMAF = "CMAF"
    MP4 = "MP4"
    TS = "TS"
    WEBM = "WEBM"
    MP3 = "MP3"
    MXF = "MXF"
    PROGRESSIVE_WEBM = "PROGRESSIVE_WEBM"
    PROGRESSIVE_MOV = "PROGRESSIVE_MOV"
    PROGRESSIVE_TS = "PROGRESSIVE_TS"
    BROADCAST_TS = "BROADCAST_TS"
    CHUNKED_TEXT = "CHUNKED_TEXT"
    TEXT = "TEXT"
    SEGMENTED_RAW = "SEGMENTED_RAW"
    PACKED_AUDIO = "PACKED_AUDIO"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.availability_start_time_mode import AvailabilityStartTimeMode
import pprint
import six


class LiveDashManifest(object):
    @poscheck_model
    def __init__(self,
                 manifest_id=None,
                 timeshift=None,
                 live_edge_offset=None,
                 suggested_presentation_delay=None,
                 minimum_update_period=None,
                 availability_start_time_mode=None):
        # type: (string_types, float, float, float, float, AvailabilityStartTimeMode) -> None

        self._manifest_id = None
        self._timeshift = None
        self._live_edge_offset = None
        self._suggested_presentation_delay = None
        self._minimum_update_period = None
        self._availability_start_time_mode = None
        self.discriminator = None

        if manifest_id is not None:
            self.manifest_id = manifest_id
        if timeshift is not None:
            self.timeshift = timeshift
        if live_edge_offset is not None:
            self.live_edge_offset = live_edge_offset
        if suggested_presentation_delay is not None:
            self.suggested_presentation_delay = suggested_presentation_delay
        if minimum_update_period is not None:
            self.minimum_update_period = minimum_update_period
        if availability_start_time_mode is not None:
            self.availability_start_time_mode = availability_start_time_mode

    @property
    def openapi_types(self):
        types = {
            'manifest_id': 'string_types',
            'timeshift': 'float',
            'live_edge_offset': 'float',
            'suggested_presentation_delay': 'float',
            'minimum_update_period': 'float',
            'availability_start_time_mode': 'AvailabilityStartTimeMode'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'manifest_id': 'manifestId',
            'timeshift': 'timeshift',
            'live_edge_offset': 'liveEdgeOffset',
            'suggested_presentation_delay': 'suggestedPresentationDelay',
            'minimum_update_period': 'minimumUpdatePeriod',
            'availability_start_time_mode': 'availabilityStartTimeMode'
        }
        return attributes

    @property
    def manifest_id(self):
        # type: () -> string_types
        """Gets the manifest_id of this LiveDashManifest.

        Dash manifest id (required)

        :return: The manifest_id of this LiveDashManifest.
        :rtype: string_types
        """
        return self._manifest_id

    @manifest_id.setter
    def manifest_id(self, manifest_id):
        # type: (string_types) -> None
        """Sets the manifest_id of this LiveDashManifest.

        Dash manifest id (required)

        :param manifest_id: The manifest_id of this LiveDashManifest.
        :type: string_types
        """

        if manifest_id is not None:
            if not isinstance(manifest_id, string_types):
                raise TypeError("Invalid type for `manifest_id`, type has to be `string_types`")

        self._manifest_id = manifest_id

    @property
    def timeshift(self):
        # type: () -> float
        """Gets the timeshift of this LiveDashManifest.

        Timeshift in seconds

        :return: The timeshift of this LiveDashManifest.
        :rtype: float
        """
        return self._timeshift

    @timeshift.setter
    def timeshift(self, timeshift):
        # type: (float) -> None
        """Sets the timeshift of this LiveDashManifest.

        Timeshift in seconds

        :param timeshift: The timeshift of this LiveDashManifest.
        :type: float
        """

        if timeshift is not None:
            if not isinstance(timeshift, (float, int)):
                raise TypeError("Invalid type for `timeshift`, type has to be `float`")

        self._timeshift = timeshift

    @property
    def live_edge_offset(self):
        # type: () -> float
        """Gets the live_edge_offset of this LiveDashManifest.

        Live edge offset in seconds

        :return: The live_edge_offset of this LiveDashManifest.
        :rtype: float
        """
        return self._live_edge_offset

    @live_edge_offset.setter
    def live_edge_offset(self, live_edge_offset):
        # type: (float) -> None
        """Sets the live_edge_offset of this LiveDashManifest.

        Live edge offset in seconds

        :param live_edge_offset: The live_edge_offset of this LiveDashManifest.
        :type: float
        """

        if live_edge_offset is not None:
            if not isinstance(live_edge_offset, (float, int)):
                raise TypeError("Invalid type for `live_edge_offset`, type has to be `float`")

        self._live_edge_offset = live_edge_offset

    @property
    def suggested_presentation_delay(self):
        # type: () -> float
        """Gets the suggested_presentation_delay of this LiveDashManifest.

        The suggestedPresentationDelay to be set in the DASH manifest. If nothing is set, no value will be set.

        :return: The suggested_presentation_delay of this LiveDashManifest.
        :rtype: float
        """
        return self._suggested_presentation_delay

    @suggested_presentation_delay.setter
    def suggested_presentation_delay(self, suggested_presentation_delay):
        # type: (float) -> None
        """Sets the suggested_presentation_delay of this LiveDashManifest.

        The suggestedPresentationDelay to be set in the DASH manifest. If nothing is set, no value will be set.

        :param suggested_presentation_delay: The suggested_presentation_delay of this LiveDashManifest.
        :type: float
        """

        if suggested_presentation_delay is not None:
            if not isinstance(suggested_presentation_delay, (float, int)):
                raise TypeError("Invalid type for `suggested_presentation_delay`, type has to be `float`")

        self._suggested_presentation_delay = suggested_presentation_delay

    @property
    def minimum_update_period(self):
        # type: () -> float
        """Gets the minimum_update_period of this LiveDashManifest.

        The minimumUpdatePeriod to be set in the DASH manifest. If nothing is set, the segment duration will be set.

        :return: The minimum_update_period of this LiveDashManifest.
        :rtype: float
        """
        return self._minimum_update_period

    @minimum_update_period.setter
    def minimum_update_period(self, minimum_update_period):
        # type: (float) -> None
        """Sets the minimum_update_period of this LiveDashManifest.

        The minimumUpdatePeriod to be set in the DASH manifest. If nothing is set, the segment duration will be set.

        :param minimum_update_period: The minimum_update_period of this LiveDashManifest.
        :type: float
        """

        if minimum_update_period is not None:
            if not isinstance(minimum_update_period, (float, int)):
                raise TypeError("Invalid type for `minimum_update_period`, type has to be `float`")

        self._minimum_update_period = minimum_update_period

    @property
    def availability_start_time_mode(self):
        # type: () -> AvailabilityStartTimeMode
        """Gets the availability_start_time_mode of this LiveDashManifest.

        The mode to trigger the availabilityStartTime initialization.

        :return: The availability_start_time_mode of this LiveDashManifest.
        :rtype: AvailabilityStartTimeMode
        """
        return self._availability_start_time_mode

    @availability_start_time_mode.setter
    def availability_start_time_mode(self, availability_start_time_mode):
        # type: (AvailabilityStartTimeMode) -> None
        """Sets the availability_start_time_mode of this LiveDashManifest.

        The mode to trigger the availabilityStartTime initialization.

        :param availability_start_time_mode: The availability_start_time_mode of this LiveDashManifest.
        :type: AvailabilityStartTimeMode
        """

        if availability_start_time_mode is not None:
            if not isinstance(availability_start_time_mode, AvailabilityStartTimeMode):
                raise TypeError("Invalid type for `availability_start_time_mode`, type has to be `AvailabilityStartTimeMode`")

        self._availability_start_time_mode = availability_start_time_mode

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LiveDashManifest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class DolbyDigitalDynamicRangeCompressionMode(Enum):
    NONE = "NONE"
    FILM_STANDARD = "FILM_STANDARD"
    FILM_LIGHT = "FILM_LIGHT"
    MUSIC_STANDARD = "MUSIC_STANDARD"
    MUSIC_LIGHT = "MUSIC_LIGHT"
    SPEECH = "SPEECH"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class BitmovinStreamQuality(Enum):
    NONE = "NONE"
    PREVIEW = "PREVIEW"
    DEFAULT = "DEFAULT"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.player_third_party_licensing_error_action import PlayerThirdPartyLicensingErrorAction
import pprint
import six


class PlayerThirdPartyLicensing(object):
    @poscheck_model
    def __init__(self,
                 license_check_server=None,
                 license_check_timeout=None,
                 error_action=None,
                 timeout_action=None):
        # type: (string_types, int, PlayerThirdPartyLicensingErrorAction, PlayerThirdPartyLicensingErrorAction) -> None

        self._license_check_server = None
        self._license_check_timeout = None
        self._error_action = None
        self._timeout_action = None
        self.discriminator = None

        if license_check_server is not None:
            self.license_check_server = license_check_server
        if license_check_timeout is not None:
            self.license_check_timeout = license_check_timeout
        if error_action is not None:
            self.error_action = error_action
        if timeout_action is not None:
            self.timeout_action = timeout_action

    @property
    def openapi_types(self):
        types = {
            'license_check_server': 'string_types',
            'license_check_timeout': 'int',
            'error_action': 'PlayerThirdPartyLicensingErrorAction',
            'timeout_action': 'PlayerThirdPartyLicensingErrorAction'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'license_check_server': 'licenseCheckServer',
            'license_check_timeout': 'licenseCheckTimeout',
            'error_action': 'errorAction',
            'timeout_action': 'timeoutAction'
        }
        return attributes

    @property
    def license_check_server(self):
        # type: () -> string_types
        """Gets the license_check_server of this PlayerThirdPartyLicensing.

        URL to your license check server (required)

        :return: The license_check_server of this PlayerThirdPartyLicensing.
        :rtype: string_types
        """
        return self._license_check_server

    @license_check_server.setter
    def license_check_server(self, license_check_server):
        # type: (string_types) -> None
        """Sets the license_check_server of this PlayerThirdPartyLicensing.

        URL to your license check server (required)

        :param license_check_server: The license_check_server of this PlayerThirdPartyLicensing.
        :type: string_types
        """

        if license_check_server is not None:
            if not isinstance(license_check_server, string_types):
                raise TypeError("Invalid type for `license_check_server`, type has to be `string_types`")

        self._license_check_server = license_check_server

    @property
    def license_check_timeout(self):
        # type: () -> int
        """Gets the license_check_timeout of this PlayerThirdPartyLicensing.

        Timeout in ms (required)

        :return: The license_check_timeout of this PlayerThirdPartyLicensing.
        :rtype: int
        """
        return self._license_check_timeout

    @license_check_timeout.setter
    def license_check_timeout(self, license_check_timeout):
        # type: (int) -> None
        """Sets the license_check_timeout of this PlayerThirdPartyLicensing.

        Timeout in ms (required)

        :param license_check_timeout: The license_check_timeout of this PlayerThirdPartyLicensing.
        :type: int
        """

        if license_check_timeout is not None:
            if license_check_timeout is not None and license_check_timeout > 2000:
                raise ValueError("Invalid value for `license_check_timeout`, must be a value less than or equal to `2000`")
            if license_check_timeout is not None and license_check_timeout < 100:
                raise ValueError("Invalid value for `license_check_timeout`, must be a value greater than or equal to `100`")
            if not isinstance(license_check_timeout, int):
                raise TypeError("Invalid type for `license_check_timeout`, type has to be `int`")

        self._license_check_timeout = license_check_timeout

    @property
    def error_action(self):
        # type: () -> PlayerThirdPartyLicensingErrorAction
        """Gets the error_action of this PlayerThirdPartyLicensing.

        Specify if the Licensing Request should fail or not on Third Party Licensing Error (required)

        :return: The error_action of this PlayerThirdPartyLicensing.
        :rtype: PlayerThirdPartyLicensingErrorAction
        """
        return self._error_action

    @error_action.setter
    def error_action(self, error_action):
        # type: (PlayerThirdPartyLicensingErrorAction) -> None
        """Sets the error_action of this PlayerThirdPartyLicensing.

        Specify if the Licensing Request should fail or not on Third Party Licensing Error (required)

        :param error_action: The error_action of this PlayerThirdPartyLicensing.
        :type: PlayerThirdPartyLicensingErrorAction
        """

        if error_action is not None:
            if not isinstance(error_action, PlayerThirdPartyLicensingErrorAction):
                raise TypeError("Invalid type for `error_action`, type has to be `PlayerThirdPartyLicensingErrorAction`")

        self._error_action = error_action

    @property
    def timeout_action(self):
        # type: () -> PlayerThirdPartyLicensingErrorAction
        """Gets the timeout_action of this PlayerThirdPartyLicensing.

        Specify if the Licensing Request should fail or not on Third Party Licensing timeout (required)

        :return: The timeout_action of this PlayerThirdPartyLicensing.
        :rtype: PlayerThirdPartyLicensingErrorAction
        """
        return self._timeout_action

    @timeout_action.setter
    def timeout_action(self, timeout_action):
        # type: (PlayerThirdPartyLicensingErrorAction) -> None
        """Sets the timeout_action of this PlayerThirdPartyLicensing.

        Specify if the Licensing Request should fail or not on Third Party Licensing timeout (required)

        :param timeout_action: The timeout_action of this PlayerThirdPartyLicensing.
        :type: PlayerThirdPartyLicensingErrorAction
        """

        if timeout_action is not None:
            if not isinstance(timeout_action, PlayerThirdPartyLicensingErrorAction):
                raise TypeError("Invalid type for `timeout_action`, type has to be `PlayerThirdPartyLicensingErrorAction`")

        self._timeout_action = timeout_action

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PlayerThirdPartyLicensing):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.abstract_condition import AbstractCondition
from bitmovin_api_sdk.models.applied_stream_settings import AppliedStreamSettings
from bitmovin_api_sdk.models.bitmovin_resource import BitmovinResource
from bitmovin_api_sdk.models.decoding_error_mode import DecodingErrorMode
from bitmovin_api_sdk.models.encoding_mode import EncodingMode
from bitmovin_api_sdk.models.stream_metadata import StreamMetadata
from bitmovin_api_sdk.models.stream_mode import StreamMode
from bitmovin_api_sdk.models.stream_per_title_settings import StreamPerTitleSettings
import pprint
import six


class Stream(BitmovinResource):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 input_streams=None,
                 outputs=None,
                 create_quality_meta_data=None,
                 codec_config_id=None,
                 segments_encoded=None,
                 conditions=None,
                 ignored_by=None,
                 mode=None,
                 selected_encoding_mode=None,
                 per_title_settings=None,
                 metadata=None,
                 decoding_error_mode=None,
                 applied_settings=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, list[StreamInput], list[EncodingOutput], bool, string_types, int, AbstractCondition, list[Ignoring], StreamMode, EncodingMode, StreamPerTitleSettings, StreamMetadata, DecodingErrorMode, AppliedStreamSettings) -> None
        super(Stream, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._input_streams = list()
        self._outputs = list()
        self._create_quality_meta_data = None
        self._codec_config_id = None
        self._segments_encoded = None
        self._conditions = None
        self._ignored_by = list()
        self._mode = None
        self._selected_encoding_mode = None
        self._per_title_settings = None
        self._metadata = None
        self._decoding_error_mode = None
        self._applied_settings = None
        self.discriminator = None

        if input_streams is not None:
            self.input_streams = input_streams
        if outputs is not None:
            self.outputs = outputs
        if create_quality_meta_data is not None:
            self.create_quality_meta_data = create_quality_meta_data
        if codec_config_id is not None:
            self.codec_config_id = codec_config_id
        if segments_encoded is not None:
            self.segments_encoded = segments_encoded
        if conditions is not None:
            self.conditions = conditions
        if ignored_by is not None:
            self.ignored_by = ignored_by
        if mode is not None:
            self.mode = mode
        if selected_encoding_mode is not None:
            self.selected_encoding_mode = selected_encoding_mode
        if per_title_settings is not None:
            self.per_title_settings = per_title_settings
        if metadata is not None:
            self.metadata = metadata
        if decoding_error_mode is not None:
            self.decoding_error_mode = decoding_error_mode
        if applied_settings is not None:
            self.applied_settings = applied_settings

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(Stream, self), 'openapi_types'):
            types = getattr(super(Stream, self), 'openapi_types')

        types.update({
            'input_streams': 'list[StreamInput]',
            'outputs': 'list[EncodingOutput]',
            'create_quality_meta_data': 'bool',
            'codec_config_id': 'string_types',
            'segments_encoded': 'int',
            'conditions': 'AbstractCondition',
            'ignored_by': 'list[Ignoring]',
            'mode': 'StreamMode',
            'selected_encoding_mode': 'EncodingMode',
            'per_title_settings': 'StreamPerTitleSettings',
            'metadata': 'StreamMetadata',
            'decoding_error_mode': 'DecodingErrorMode',
            'applied_settings': 'AppliedStreamSettings'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(Stream, self), 'attribute_map'):
            attributes = getattr(super(Stream, self), 'attribute_map')

        attributes.update({
            'input_streams': 'inputStreams',
            'outputs': 'outputs',
            'create_quality_meta_data': 'createQualityMetaData',
            'codec_config_id': 'codecConfigId',
            'segments_encoded': 'segmentsEncoded',
            'conditions': 'conditions',
            'ignored_by': 'ignoredBy',
            'mode': 'mode',
            'selected_encoding_mode': 'selectedEncodingMode',
            'per_title_settings': 'perTitleSettings',
            'metadata': 'metadata',
            'decoding_error_mode': 'decodingErrorMode',
            'applied_settings': 'appliedSettings'
        })
        return attributes

    @property
    def input_streams(self):
        # type: () -> list[StreamInput]
        """Gets the input_streams of this Stream.

        Determines the input source(s) for the stream. All video streams of an encoding need to have identical input configurations (required)

        :return: The input_streams of this Stream.
        :rtype: list[StreamInput]
        """
        return self._input_streams

    @input_streams.setter
    def input_streams(self, input_streams):
        # type: (list) -> None
        """Sets the input_streams of this Stream.

        Determines the input source(s) for the stream. All video streams of an encoding need to have identical input configurations (required)

        :param input_streams: The input_streams of this Stream.
        :type: list[StreamInput]
        """

        if input_streams is not None:
            if not isinstance(input_streams, list):
                raise TypeError("Invalid type for `input_streams`, type has to be `list[StreamInput]`")

        self._input_streams = input_streams

    @property
    def outputs(self):
        # type: () -> list[EncodingOutput]
        """Gets the outputs of this Stream.


        :return: The outputs of this Stream.
        :rtype: list[EncodingOutput]
        """
        return self._outputs

    @outputs.setter
    def outputs(self, outputs):
        # type: (list) -> None
        """Sets the outputs of this Stream.


        :param outputs: The outputs of this Stream.
        :type: list[EncodingOutput]
        """

        if outputs is not None:
            if not isinstance(outputs, list):
                raise TypeError("Invalid type for `outputs`, type has to be `list[EncodingOutput]`")

        self._outputs = outputs

    @property
    def create_quality_meta_data(self):
        # type: () -> bool
        """Gets the create_quality_meta_data of this Stream.

        Set true to create quality metadata for this stream

        :return: The create_quality_meta_data of this Stream.
        :rtype: bool
        """
        return self._create_quality_meta_data

    @create_quality_meta_data.setter
    def create_quality_meta_data(self, create_quality_meta_data):
        # type: (bool) -> None
        """Sets the create_quality_meta_data of this Stream.

        Set true to create quality metadata for this stream

        :param create_quality_meta_data: The create_quality_meta_data of this Stream.
        :type: bool
        """

        if create_quality_meta_data is not None:
            if not isinstance(create_quality_meta_data, bool):
                raise TypeError("Invalid type for `create_quality_meta_data`, type has to be `bool`")

        self._create_quality_meta_data = create_quality_meta_data

    @property
    def codec_config_id(self):
        # type: () -> string_types
        """Gets the codec_config_id of this Stream.

        Id of the codec configuration (required)

        :return: The codec_config_id of this Stream.
        :rtype: string_types
        """
        return self._codec_config_id

    @codec_config_id.setter
    def codec_config_id(self, codec_config_id):
        # type: (string_types) -> None
        """Sets the codec_config_id of this Stream.

        Id of the codec configuration (required)

        :param codec_config_id: The codec_config_id of this Stream.
        :type: string_types
        """

        if codec_config_id is not None:
            if not isinstance(codec_config_id, string_types):
                raise TypeError("Invalid type for `codec_config_id`, type has to be `string_types`")

        self._codec_config_id = codec_config_id

    @property
    def segments_encoded(self):
        # type: () -> int
        """Gets the segments_encoded of this Stream.

        Number of encoded segments. Available after encoding finishes.

        :return: The segments_encoded of this Stream.
        :rtype: int
        """
        return self._segments_encoded

    @segments_encoded.setter
    def segments_encoded(self, segments_encoded):
        # type: (int) -> None
        """Sets the segments_encoded of this Stream.

        Number of encoded segments. Available after encoding finishes.

        :param segments_encoded: The segments_encoded of this Stream.
        :type: int
        """

        if segments_encoded is not None:
            if not isinstance(segments_encoded, int):
                raise TypeError("Invalid type for `segments_encoded`, type has to be `int`")

        self._segments_encoded = segments_encoded

    @property
    def conditions(self):
        # type: () -> AbstractCondition
        """Gets the conditions of this Stream.

        Defines a condition that is evaluated against the input of the Stream. If the condition is not fulfilled, the Stream will be ignored during the encoding process. The 'streamConditionMode' of a Muxing allows to control how ignored Streams affect the Muxing. When retrieving the resource after the analysis step of the encoding has finished, 'ignoredBy' will indicate if and why it has been ignored. See [Stream Conditions](https://bitmovin.com/docs/encoding/articles/stream-conditions) for more information

        :return: The conditions of this Stream.
        :rtype: AbstractCondition
        """
        return self._conditions

    @conditions.setter
    def conditions(self, conditions):
        # type: (AbstractCondition) -> None
        """Sets the conditions of this Stream.

        Defines a condition that is evaluated against the input of the Stream. If the condition is not fulfilled, the Stream will be ignored during the encoding process. The 'streamConditionMode' of a Muxing allows to control how ignored Streams affect the Muxing. When retrieving the resource after the analysis step of the encoding has finished, 'ignoredBy' will indicate if and why it has been ignored. See [Stream Conditions](https://bitmovin.com/docs/encoding/articles/stream-conditions) for more information

        :param conditions: The conditions of this Stream.
        :type: AbstractCondition
        """

        if conditions is not None:
            if not isinstance(conditions, AbstractCondition):
                raise TypeError("Invalid type for `conditions`, type has to be `AbstractCondition`")

        self._conditions = conditions

    @property
    def ignored_by(self):
        # type: () -> list[Ignoring]
        """Gets the ignored_by of this Stream.

        This read-only property is set during the analysis step of the encoding. If it contains items, the Stream has been ignored during the encoding process due to its 'conditions'

        :return: The ignored_by of this Stream.
        :rtype: list[Ignoring]
        """
        return self._ignored_by

    @ignored_by.setter
    def ignored_by(self, ignored_by):
        # type: (list) -> None
        """Sets the ignored_by of this Stream.

        This read-only property is set during the analysis step of the encoding. If it contains items, the Stream has been ignored during the encoding process due to its 'conditions'

        :param ignored_by: The ignored_by of this Stream.
        :type: list[Ignoring]
        """

        if ignored_by is not None:
            if not isinstance(ignored_by, list):
                raise TypeError("Invalid type for `ignored_by`, type has to be `list[Ignoring]`")

        self._ignored_by = ignored_by

    @property
    def mode(self):
        # type: () -> StreamMode
        """Gets the mode of this Stream.

        Mode of the stream

        :return: The mode of this Stream.
        :rtype: StreamMode
        """
        return self._mode

    @mode.setter
    def mode(self, mode):
        # type: (StreamMode) -> None
        """Sets the mode of this Stream.

        Mode of the stream

        :param mode: The mode of this Stream.
        :type: StreamMode
        """

        if mode is not None:
            if not isinstance(mode, StreamMode):
                raise TypeError("Invalid type for `mode`, type has to be `StreamMode`")

        self._mode = mode

    @property
    def selected_encoding_mode(self):
        # type: () -> EncodingMode
        """Gets the selected_encoding_mode of this Stream.

        The encoding mode of the stream which was applied by the assigned codec configuration

        :return: The selected_encoding_mode of this Stream.
        :rtype: EncodingMode
        """
        return self._selected_encoding_mode

    @selected_encoding_mode.setter
    def selected_encoding_mode(self, selected_encoding_mode):
        # type: (EncodingMode) -> None
        """Sets the selected_encoding_mode of this Stream.

        The encoding mode of the stream which was applied by the assigned codec configuration

        :param selected_encoding_mode: The selected_encoding_mode of this Stream.
        :type: EncodingMode
        """

        if selected_encoding_mode is not None:
            if not isinstance(selected_encoding_mode, EncodingMode):
                raise TypeError("Invalid type for `selected_encoding_mode`, type has to be `EncodingMode`")

        self._selected_encoding_mode = selected_encoding_mode

    @property
    def per_title_settings(self):
        # type: () -> StreamPerTitleSettings
        """Gets the per_title_settings of this Stream.

        Settings to configure Per-Title on stream level

        :return: The per_title_settings of this Stream.
        :rtype: StreamPerTitleSettings
        """
        return self._per_title_settings

    @per_title_settings.setter
    def per_title_settings(self, per_title_settings):
        # type: (StreamPerTitleSettings) -> None
        """Sets the per_title_settings of this Stream.

        Settings to configure Per-Title on stream level

        :param per_title_settings: The per_title_settings of this Stream.
        :type: StreamPerTitleSettings
        """

        if per_title_settings is not None:
            if not isinstance(per_title_settings, StreamPerTitleSettings):
                raise TypeError("Invalid type for `per_title_settings`, type has to be `StreamPerTitleSettings`")

        self._per_title_settings = per_title_settings

    @property
    def metadata(self):
        # type: () -> StreamMetadata
        """Gets the metadata of this Stream.


        :return: The metadata of this Stream.
        :rtype: StreamMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        # type: (StreamMetadata) -> None
        """Sets the metadata of this Stream.


        :param metadata: The metadata of this Stream.
        :type: StreamMetadata
        """

        if metadata is not None:
            if not isinstance(metadata, StreamMetadata):
                raise TypeError("Invalid type for `metadata`, type has to be `StreamMetadata`")

        self._metadata = metadata

    @property
    def decoding_error_mode(self):
        # type: () -> DecodingErrorMode
        """Gets the decoding_error_mode of this Stream.

        Determines how to react to errors during decoding

        :return: The decoding_error_mode of this Stream.
        :rtype: DecodingErrorMode
        """
        return self._decoding_error_mode

    @decoding_error_mode.setter
    def decoding_error_mode(self, decoding_error_mode):
        # type: (DecodingErrorMode) -> None
        """Sets the decoding_error_mode of this Stream.

        Determines how to react to errors during decoding

        :param decoding_error_mode: The decoding_error_mode of this Stream.
        :type: DecodingErrorMode
        """

        if decoding_error_mode is not None:
            if not isinstance(decoding_error_mode, DecodingErrorMode):
                raise TypeError("Invalid type for `decoding_error_mode`, type has to be `DecodingErrorMode`")

        self._decoding_error_mode = decoding_error_mode

    @property
    def applied_settings(self):
        # type: () -> AppliedStreamSettings
        """Gets the applied_settings of this Stream.

        Contains stream properties which may not have been defined in the configuration

        :return: The applied_settings of this Stream.
        :rtype: AppliedStreamSettings
        """
        return self._applied_settings

    @applied_settings.setter
    def applied_settings(self, applied_settings):
        # type: (AppliedStreamSettings) -> None
        """Sets the applied_settings of this Stream.

        Contains stream properties which may not have been defined in the configuration

        :param applied_settings: The applied_settings of this Stream.
        :type: AppliedStreamSettings
        """

        if applied_settings is not None:
            if not isinstance(applied_settings, AppliedStreamSettings):
                raise TypeError("Invalid type for `applied_settings`, type has to be `AppliedStreamSettings`")

        self._applied_settings = applied_settings

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(Stream, self), "to_dict"):
            result = super(Stream, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Stream):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.webhook import Webhook
from bitmovin_api_sdk.notifications.webhooks.encoding.encodings.error.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.notifications.webhooks.encoding.encodings.error.webhook_list_query_params import WebhookListQueryParams
from bitmovin_api_sdk.notifications.webhooks.encoding.encodings.error.webhook_list_by_encoding_id_query_params import WebhookListByEncodingIdQueryParams


class ErrorApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(ErrorApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.customdata = CustomdataApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, webhook, **kwargs):
        # type: (Webhook, dict) -> Webhook
        """Add &#39;Encoding Error&#39; Webhook

        :param webhook: The &#39;Encoding Error&#39; Webhook to be added. A maximum number of 5 webhooks is allowed
        :type webhook: Webhook, required
        :return: Webhook Details
        :rtype: Webhook
        """

        return self.api_client.post(
            '/notifications/webhooks/encoding/encodings/error',
            webhook,
            type=Webhook,
            **kwargs
        )

    def create_by_encoding_id(self, encoding_id, webhook, **kwargs):
        # type: (string_types, Webhook, dict) -> Webhook
        """Add Error Webhook for a specific Encoding

        :param encoding_id: Id of the encoding
        :type encoding_id: string_types, required
        :param webhook: The &#39;Encoding Error&#39; Webhook to be added. A maximum number of 5 webhooks per Encoding is allowed
        :type webhook: Webhook, required
        :return: Webhook Details
        :rtype: Webhook
        """

        return self.api_client.post(
            '/notifications/webhooks/encoding/encodings/{encoding_id}/error',
            webhook,
            path_params={'encoding_id': encoding_id},
            type=Webhook,
            **kwargs
        )

    def delete_by_encoding_id_and_webhook_id(self, encoding_id, webhook_id, **kwargs):
        # type: (string_types, string_types, dict) -> BitmovinResponse
        """Delete &#39;Encoding Error&#39; Webhook for a specific Encoding

        :param encoding_id: Id of the encoding
        :type encoding_id: string_types, required
        :param webhook_id: Id of the webhook
        :type webhook_id: string_types, required
        :return: Id of the webhook
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/notifications/webhooks/encoding/encodings/{encoding_id}/error/{webhook_id}',
            path_params={'encoding_id': encoding_id, 'webhook_id': webhook_id},
            type=BitmovinResponse,
            **kwargs
        )

    def delete_by_webhook_id(self, webhook_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Delete &#39;Encoding Error&#39; Webhook

        :param webhook_id: Id of the webhook
        :type webhook_id: string_types, required
        :return: Id of the webhook
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/notifications/webhooks/encoding/encodings/error/{webhook_id}',
            path_params={'webhook_id': webhook_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get_by_encoding_id_and_webhook_id(self, encoding_id, webhook_id, **kwargs):
        # type: (string_types, string_types, dict) -> Webhook
        """&#39;Encoding Error&#39; Webhook Details for a specific Encoding

        :param encoding_id: Id of the encoding
        :type encoding_id: string_types, required
        :param webhook_id: Id of the webhook
        :type webhook_id: string_types, required
        :return: Webhook Details
        :rtype: Webhook
        """

        return self.api_client.get(
            '/notifications/webhooks/encoding/encodings/{encoding_id}/error/{webhook_id}',
            path_params={'encoding_id': encoding_id, 'webhook_id': webhook_id},
            type=Webhook,
            **kwargs
        )

    def get_by_webhook_id(self, webhook_id, **kwargs):
        # type: (string_types, dict) -> Webhook
        """&#39;Encoding Error&#39; Webhook Details

        :param webhook_id: Id of the webhook
        :type webhook_id: string_types, required
        :return: Webhook Details
        :rtype: Webhook
        """

        return self.api_client.get(
            '/notifications/webhooks/encoding/encodings/error/{webhook_id}',
            path_params={'webhook_id': webhook_id},
            type=Webhook,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (WebhookListQueryParams, dict) -> Webhook
        """List &#39;Encoding Error&#39; Webhooks

        :param query_params: Query parameters
        :type query_params: WebhookListQueryParams
        :return: List of 'Encoding Error' Webhooks
        :rtype: Webhook
        """

        return self.api_client.get(
            '/notifications/webhooks/encoding/encodings/error',
            query_params=query_params,
            pagination_response=True,
            type=Webhook,
            **kwargs
        )

    def list_by_encoding_id(self, encoding_id, query_params=None, **kwargs):
        # type: (string_types, WebhookListByEncodingIdQueryParams, dict) -> Webhook
        """List &#39;Encoding Error&#39; Webhooks for a specific Encoding

        :param encoding_id: Id of the encoding
        :type encoding_id: string_types, required
        :param query_params: Query parameters
        :type query_params: WebhookListByEncodingIdQueryParams
        :return: List of 'Encoding Error' Webhooks
        :rtype: Webhook
        """

        return self.api_client.get(
            '/notifications/webhooks/encoding/encodings/{encoding_id}/error',
            path_params={'encoding_id': encoding_id},
            query_params=query_params,
            pagination_response=True,
            type=Webhook,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class ChromaLocation(Enum):
    UNSPECIFIED = "UNSPECIFIED"
    LEFT = "LEFT"
    CENTER = "CENTER"
    TOPLEFT = "TOPLEFT"
    TOP = "TOP"
    BOTTOMLEFT = "BOTTOMLEFT"
    BOTTOM = "BOTTOM"



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.watch_folder import WatchFolder
from bitmovin_api_sdk.encoding.watch_folders.watch_folder_list_query_params import WatchFolderListQueryParams


class WatchFoldersApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(WatchFoldersApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, watch_folder, **kwargs):
        # type: (WatchFolder, dict) -> WatchFolder
        """Create Watch Folder

        :param watch_folder: The Watch Folder to be created
        :type watch_folder: WatchFolder, required
        :return: Watch Folder
        :rtype: WatchFolder
        """

        return self.api_client.post(
            '/encoding/watch-folders',
            watch_folder,
            type=WatchFolder,
            **kwargs
        )

    def delete(self, watch_folder_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Delete Watch Folder

        :param watch_folder_id: Id of the Watch Folder
        :type watch_folder_id: string_types, required
        :return: Id of the Watch Folder that was deleted
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/watch-folders/{watch_folder_id}',
            path_params={'watch_folder_id': watch_folder_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, watch_folder_id, **kwargs):
        # type: (string_types, dict) -> WatchFolder
        """Watch Folder details

        :param watch_folder_id: Id of the Watch Folder
        :type watch_folder_id: string_types, required
        :return: Watch Folder
        :rtype: WatchFolder
        """

        return self.api_client.get(
            '/encoding/watch-folders/{watch_folder_id}',
            path_params={'watch_folder_id': watch_folder_id},
            type=WatchFolder,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (WatchFolderListQueryParams, dict) -> WatchFolder
        """List all Watch Folders

        :param query_params: Query parameters
        :type query_params: WatchFolderListQueryParams
        :return: List of Watch Folders
        :rtype: WatchFolder
        """

        return self.api_client.get(
            '/encoding/watch-folders',
            query_params=query_params,
            pagination_response=True,
            type=WatchFolder,
            **kwargs
        )

    def start(self, watch_folder_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Start Watch Folder

        :param watch_folder_id: Id of the Watch Folder
        :type watch_folder_id: string_types, required
        :return: Id of the Watch Folder
        :rtype: BitmovinResponse
        """

        return self.api_client.post(
            '/encoding/watch-folders/{watch_folder_id}/start',
            path_params={'watch_folder_id': watch_folder_id},
            type=BitmovinResponse,
            **kwargs
        )

    def stop(self, watch_folder_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Stop Watch Folder

        :param watch_folder_id: Id of the Watch Folder
        :type watch_folder_id: string_types, required
        :return: Id of the Watch Folder
        :rtype: BitmovinResponse
        """

        return self.api_client.post(
            '/encoding/watch-folders/{watch_folder_id}/stop',
            path_params={'watch_folder_id': watch_folder_id},
            type=BitmovinResponse,
            **kwargs
        )



from bitmovin_api_sdk.encoding.manifests.smooth.representations.mp4.mp4_api import Mp4Api
from bitmovin_api_sdk.encoding.manifests.smooth.representations.mp4.smooth_streaming_representation_list_query_params import SmoothStreamingRepresentationListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class HeAacV2Signaling(Enum):
    IMPLICIT = "IMPLICIT"
    EXPLICIT_SBR = "EXPLICIT_SBR"
    EXPLICIT_PS = "EXPLICIT_PS"
    EXPLICIT_HIERARCHICAL = "EXPLICIT_HIERARCHICAL"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class LiveEncodingStatus(Enum):
    CONNECTED = "CONNECTED"
    DISCONNECTED = "DISCONNECTED"
    WAITING_FOR_FIRST_CONNECT = "WAITING_FOR_FIRST_CONNECT"
    ERROR = "ERROR"
    NOT_AVAILABLE = "NOT_AVAILABLE"
    FINISHED = "FINISHED"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class DeinterlaceAutoEnable(Enum):
    ALWAYS_ON = "ALWAYS_ON"
    META_DATA_BASED = "META_DATA_BASED"
    META_DATA_AND_CONTENT_BASED = "META_DATA_AND_CONTENT_BASED"



from bitmovin_api_sdk.encoding.encodings.muxings.mp4.drm.drm_api import DrmApi
from bitmovin_api_sdk.encoding.encodings.muxings.mp4.drm.playready.playready_api import PlayreadyApi
from bitmovin_api_sdk.encoding.encodings.muxings.mp4.drm.clearkey.clearkey_api import ClearkeyApi
from bitmovin_api_sdk.encoding.encodings.muxings.mp4.drm.widevine.widevine_api import WidevineApi
from bitmovin_api_sdk.encoding.encodings.muxings.mp4.drm.marlin.marlin_api import MarlinApi
from bitmovin_api_sdk.encoding.encodings.muxings.mp4.drm.cenc.cenc_api import CencApi
from bitmovin_api_sdk.encoding.encodings.muxings.mp4.drm.speke.speke_api import SpekeApi



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.dolby_digital_plus_surround_mode import DolbyDigitalPlusSurroundMode
import pprint
import six


class DolbyDigitalPlusBitstreamInfo(object):
    @poscheck_model
    def __init__(self,
                 surround_mode=None,
                 surround_ex_mode=None):
        # type: (DolbyDigitalPlusSurroundMode, DolbyDigitalPlusSurroundMode) -> None

        self._surround_mode = None
        self._surround_ex_mode = None
        self.discriminator = None

        if surround_mode is not None:
            self.surround_mode = surround_mode
        if surround_ex_mode is not None:
            self.surround_ex_mode = surround_ex_mode

    @property
    def openapi_types(self):
        types = {
            'surround_mode': 'DolbyDigitalPlusSurroundMode',
            'surround_ex_mode': 'DolbyDigitalPlusSurroundMode'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'surround_mode': 'surroundMode',
            'surround_ex_mode': 'surroundExMode'
        }
        return attributes

    @property
    def surround_mode(self):
        # type: () -> DolbyDigitalPlusSurroundMode
        """Gets the surround_mode of this DolbyDigitalPlusBitstreamInfo.

        This parameter indicates to a decoder whether the two‐channel encoded bitstream contains a Dolby Surround (Lt/Rt) program that requires Dolby Pro Logic decoding.  When downmixing to stereo from a multichannel input, set this value according to the type of downmix performed (Lt/Rt: `ENABLED`, Lo/Ro: `DISABLED`). When transcoding a stereo Dolby Digital, Dolby Digital Plus, or Dolby E input, the value must be passed through from the input bitstream to the output bitstream. When transcoding a third-party stereo input to stereo Dolby Digital set the value to `NOT_INDICATED`. 

        :return: The surround_mode of this DolbyDigitalPlusBitstreamInfo.
        :rtype: DolbyDigitalPlusSurroundMode
        """
        return self._surround_mode

    @surround_mode.setter
    def surround_mode(self, surround_mode):
        # type: (DolbyDigitalPlusSurroundMode) -> None
        """Sets the surround_mode of this DolbyDigitalPlusBitstreamInfo.

        This parameter indicates to a decoder whether the two‐channel encoded bitstream contains a Dolby Surround (Lt/Rt) program that requires Dolby Pro Logic decoding.  When downmixing to stereo from a multichannel input, set this value according to the type of downmix performed (Lt/Rt: `ENABLED`, Lo/Ro: `DISABLED`). When transcoding a stereo Dolby Digital, Dolby Digital Plus, or Dolby E input, the value must be passed through from the input bitstream to the output bitstream. When transcoding a third-party stereo input to stereo Dolby Digital set the value to `NOT_INDICATED`. 

        :param surround_mode: The surround_mode of this DolbyDigitalPlusBitstreamInfo.
        :type: DolbyDigitalPlusSurroundMode
        """

        if surround_mode is not None:
            if not isinstance(surround_mode, DolbyDigitalPlusSurroundMode):
                raise TypeError("Invalid type for `surround_mode`, type has to be `DolbyDigitalPlusSurroundMode`")

        self._surround_mode = surround_mode

    @property
    def surround_ex_mode(self):
        # type: () -> DolbyDigitalPlusSurroundMode
        """Gets the surround_ex_mode of this DolbyDigitalPlusBitstreamInfo.

        This is used to identify the encoded audio as material encoded in Dolby Digital Surround EX. This parameter is used only if the encoded audio has two surround channels.  An amplifier or receiver with Dolby Digital Surround EX decoding can use this parameter as a flag to switch the decoding on or off automatically. The behavior is similar to that of the `surroundMode` parameter. 

        :return: The surround_ex_mode of this DolbyDigitalPlusBitstreamInfo.
        :rtype: DolbyDigitalPlusSurroundMode
        """
        return self._surround_ex_mode

    @surround_ex_mode.setter
    def surround_ex_mode(self, surround_ex_mode):
        # type: (DolbyDigitalPlusSurroundMode) -> None
        """Sets the surround_ex_mode of this DolbyDigitalPlusBitstreamInfo.

        This is used to identify the encoded audio as material encoded in Dolby Digital Surround EX. This parameter is used only if the encoded audio has two surround channels.  An amplifier or receiver with Dolby Digital Surround EX decoding can use this parameter as a flag to switch the decoding on or off automatically. The behavior is similar to that of the `surroundMode` parameter. 

        :param surround_ex_mode: The surround_ex_mode of this DolbyDigitalPlusBitstreamInfo.
        :type: DolbyDigitalPlusSurroundMode
        """

        if surround_ex_mode is not None:
            if not isinstance(surround_ex_mode, DolbyDigitalPlusSurroundMode):
                raise TypeError("Invalid type for `surround_ex_mode`, type has to be `DolbyDigitalPlusSurroundMode`")

        self._surround_ex_mode = surround_ex_mode

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DolbyDigitalPlusBitstreamInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.encodings.muxings.progressive_ts.id3.id3_api import Id3Api
from bitmovin_api_sdk.encoding.encodings.muxings.progressive_ts.id3.raw.raw_api import RawApi
from bitmovin_api_sdk.encoding.encodings.muxings.progressive_ts.id3.frame_id.frame_id_api import FrameIdApi
from bitmovin_api_sdk.encoding.encodings.muxings.progressive_ts.id3.plain_text.plain_text_api import PlainTextApi
from bitmovin_api_sdk.encoding.encodings.muxings.progressive_ts.id3.id3_tag_list_query_params import Id3TagListQueryParams



from bitmovin_api_sdk.encoding.configurations.audio.mp2.mp2_api import Mp2Api
from bitmovin_api_sdk.encoding.configurations.audio.mp2.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.configurations.audio.mp2.mp2_audio_configuration_list_query_params import Mp2AudioConfigurationListQueryParams



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.account.account_api import AccountApi
from bitmovin_api_sdk.analytics.analytics_api import AnalyticsApi
from bitmovin_api_sdk.streams.streams_api import StreamsApi
from bitmovin_api_sdk.encoding.encoding_api import EncodingApi
from bitmovin_api_sdk.general.general_api import GeneralApi
from bitmovin_api_sdk.notifications.notifications_api import NotificationsApi
from bitmovin_api_sdk.player.player_api import PlayerApi


class BitmovinApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(BitmovinApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.account = AccountApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.analytics = AnalyticsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.streams = StreamsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.encoding = EncodingApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.general = GeneralApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.notifications = NotificationsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.player = PlayerApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_resource import BitmovinResource
from bitmovin_api_sdk.models.insertable_content_status import InsertableContentStatus
import pprint
import six


class InsertableContent(BitmovinResource):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 inputs=None,
                 status=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, list[InsertableContentInput], InsertableContentStatus) -> None
        super(InsertableContent, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._inputs = list()
        self._status = None
        self.discriminator = None

        if inputs is not None:
            self.inputs = inputs
        if status is not None:
            self.status = status

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(InsertableContent, self), 'openapi_types'):
            types = getattr(super(InsertableContent, self), 'openapi_types')

        types.update({
            'inputs': 'list[InsertableContentInput]',
            'status': 'InsertableContentStatus'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(InsertableContent, self), 'attribute_map'):
            attributes = getattr(super(InsertableContent, self), 'attribute_map')

        attributes.update({
            'inputs': 'inputs',
            'status': 'status'
        })
        return attributes

    @property
    def inputs(self):
        # type: () -> list[InsertableContentInput]
        """Gets the inputs of this InsertableContent.

        Either a list of movie files to be inserted in the live stream or a single image file. The movie files must have a video stream at stream position 0, which matches the codec, resolution and framerate of the livestream. The number of audio streams must also be the same and they have to match the sample format, number of channels and sample rate of the audio streams of the livestream. Supported image formats are: `.Y.U.V`, `Alias PIX`, `animated GIF`, `APNG`, `BMP`, `DPX`, `FITS`, `JPEG`, `JPEG 2000`, `JPEG-LS`, `PAM`, `PBM`, `PCX`, `PGM`, `PGMYUV`, `PNG`, `PPM`, `SGI`, `Sun Rasterfile`, `TIFF`, `Truevision Targa`, `WebP`, `XBM`, `XFace`, `XPM`, `XWD`

        :return: The inputs of this InsertableContent.
        :rtype: list[InsertableContentInput]
        """
        return self._inputs

    @inputs.setter
    def inputs(self, inputs):
        # type: (list) -> None
        """Sets the inputs of this InsertableContent.

        Either a list of movie files to be inserted in the live stream or a single image file. The movie files must have a video stream at stream position 0, which matches the codec, resolution and framerate of the livestream. The number of audio streams must also be the same and they have to match the sample format, number of channels and sample rate of the audio streams of the livestream. Supported image formats are: `.Y.U.V`, `Alias PIX`, `animated GIF`, `APNG`, `BMP`, `DPX`, `FITS`, `JPEG`, `JPEG 2000`, `JPEG-LS`, `PAM`, `PBM`, `PCX`, `PGM`, `PGMYUV`, `PNG`, `PPM`, `SGI`, `Sun Rasterfile`, `TIFF`, `Truevision Targa`, `WebP`, `XBM`, `XFace`, `XPM`, `XWD`

        :param inputs: The inputs of this InsertableContent.
        :type: list[InsertableContentInput]
        """

        if inputs is not None:
            if not isinstance(inputs, list):
                raise TypeError("Invalid type for `inputs`, type has to be `list[InsertableContentInput]`")

        self._inputs = inputs

    @property
    def status(self):
        # type: () -> InsertableContentStatus
        """Gets the status of this InsertableContent.

        Status of the insertable content.

        :return: The status of this InsertableContent.
        :rtype: InsertableContentStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        # type: (InsertableContentStatus) -> None
        """Sets the status of this InsertableContent.

        Status of the insertable content.

        :param status: The status of this InsertableContent.
        :type: InsertableContentStatus
        """

        if status is not None:
            if not isinstance(status, InsertableContentStatus):
                raise TypeError("Invalid type for `status`, type has to be `InsertableContentStatus`")

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(InsertableContent, self), "to_dict"):
            result = super(InsertableContent, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InsertableContent):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class PcmSampleFormat(Enum):
    S16LE = "S16LE"
    S24LE = "S24LE"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class ColorPrimaries(Enum):
    UNSPECIFIED = "UNSPECIFIED"
    BT709 = "BT709"
    BT470M = "BT470M"
    BT470BG = "BT470BG"
    SMPTE170M = "SMPTE170M"
    SMPTE240M = "SMPTE240M"
    FILM = "FILM"
    BT2020 = "BT2020"
    SMPTE428 = "SMPTE428"
    SMPTEST428_1 = "SMPTEST428_1"
    SMPTE431 = "SMPTE431"
    SMPTE432 = "SMPTE432"
    JEDEC_P22 = "JEDEC_P22"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class DtsXChannelLayout(Enum):
    CL_5_1 = "5.1"
    CL_5_1_4 = "5.1.4"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class ConditionOperator(Enum):
    EQUAL = "=="
    NOT_EQUAL = "!="
    LESS_THAN_OR_EQUAL = "<="
    LESS_THAN = "<"
    GREATER_THAN = ">"
    GREATER_THAN_OR_EQUAL = ">="



from bitmovin_api_sdk.encoding.simple.jobs.jobs_api import JobsApi
from bitmovin_api_sdk.encoding.simple.jobs.vod.vod_api import VodApi
from bitmovin_api_sdk.encoding.simple.jobs.live.live_api import LiveApi



from bitmovin_api_sdk.encoding.encodings.streams.streams_api import StreamsApi
from bitmovin_api_sdk.encoding.encodings.streams.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.streams.input.input_api import InputApi
from bitmovin_api_sdk.encoding.encodings.streams.inputs.inputs_api import InputsApi
from bitmovin_api_sdk.encoding.encodings.streams.filters.filters_api import FiltersApi
from bitmovin_api_sdk.encoding.encodings.streams.burn_in_subtitles.burn_in_subtitles_api import BurnInSubtitlesApi
from bitmovin_api_sdk.encoding.encodings.streams.watermarking.watermarking_api import WatermarkingApi
from bitmovin_api_sdk.encoding.encodings.streams.captions.captions_api import CaptionsApi
from bitmovin_api_sdk.encoding.encodings.streams.bifs.bifs_api import BifsApi
from bitmovin_api_sdk.encoding.encodings.streams.hdr.hdr_api import HdrApi
from bitmovin_api_sdk.encoding.encodings.streams.thumbnails.thumbnails_api import ThumbnailsApi
from bitmovin_api_sdk.encoding.encodings.streams.sprites.sprites_api import SpritesApi
from bitmovin_api_sdk.encoding.encodings.streams.qc.qc_api import QcApi
from bitmovin_api_sdk.encoding.encodings.streams.stream_list_query_params import StreamListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class QuantizationGroupSize(Enum):
    QGS_8x8 = "QGS_8x8"
    QGS_16x16 = "QGS_16x16"
    QGS_32x32 = "QGS_32x32"
    QGS_64x64 = "QGS_64x64"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class Cea608ChannelType(Enum):
    CC1 = "CC1"
    CC3 = "CC3"



from bitmovin_api_sdk.encoding.configurations.audio.ac3.ac3_api import Ac3Api
from bitmovin_api_sdk.encoding.configurations.audio.ac3.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.configurations.audio.ac3.ac3_audio_configuration_list_query_params import Ac3AudioConfigurationListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class BackupSrtInputs(object):
    @poscheck_model
    def __init__(self,
                 delay_threshold=None,
                 srt_inputs=None):
        # type: (int, list[SrtInput]) -> None

        self._delay_threshold = None
        self._srt_inputs = list()
        self.discriminator = None

        if delay_threshold is not None:
            self.delay_threshold = delay_threshold
        if srt_inputs is not None:
            self.srt_inputs = srt_inputs

    @property
    def openapi_types(self):
        types = {
            'delay_threshold': 'int',
            'srt_inputs': 'list[SrtInput]'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'delay_threshold': 'delayThreshold',
            'srt_inputs': 'srtInputs'
        }
        return attributes

    @property
    def delay_threshold(self):
        # type: () -> int
        """Gets the delay_threshold of this BackupSrtInputs.

        When there is no input signal present for this number of seconds, the encoder will switch to the next input

        :return: The delay_threshold of this BackupSrtInputs.
        :rtype: int
        """
        return self._delay_threshold

    @delay_threshold.setter
    def delay_threshold(self, delay_threshold):
        # type: (int) -> None
        """Sets the delay_threshold of this BackupSrtInputs.

        When there is no input signal present for this number of seconds, the encoder will switch to the next input

        :param delay_threshold: The delay_threshold of this BackupSrtInputs.
        :type: int
        """

        if delay_threshold is not None:
            if not isinstance(delay_threshold, int):
                raise TypeError("Invalid type for `delay_threshold`, type has to be `int`")

        self._delay_threshold = delay_threshold

    @property
    def srt_inputs(self):
        # type: () -> list[SrtInput]
        """Gets the srt_inputs of this BackupSrtInputs.


        :return: The srt_inputs of this BackupSrtInputs.
        :rtype: list[SrtInput]
        """
        return self._srt_inputs

    @srt_inputs.setter
    def srt_inputs(self, srt_inputs):
        # type: (list) -> None
        """Sets the srt_inputs of this BackupSrtInputs.


        :param srt_inputs: The srt_inputs of this BackupSrtInputs.
        :type: list[SrtInput]
        """

        if srt_inputs is not None:
            if not isinstance(srt_inputs, list):
                raise TypeError("Invalid type for `srt_inputs`, type has to be `list[SrtInput]`")

        self._srt_inputs = srt_inputs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BackupSrtInputs):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.models import CloudRegion
from bitmovin_api_sdk.models import EncodingMode


class EncodingListQueryParams(object):
    def __init__(self, offset=None, limit=None, sort=None, type_=None, status=None, cloud_region=None, selected_cloud_region=None, encoder_version=None, selected_encoder_version=None, selected_encoding_mode=None, name=None, search=None, created_at_newer_than=None, created_at_older_than=None, started_at_newer_than=None, started_at_older_than=None, finished_at_newer_than=None, finished_at_older_than=None):
        # type: (int, int, string_types, string_types, string_types, CloudRegion, CloudRegion, string_types, string_types, EncodingMode, string_types, string_types, datetime, datetime, datetime, datetime, datetime, datetime) -> None
        super(EncodingListQueryParams, self).__init__()

        self.offset = offset
        self.limit = limit
        self.sort = sort
        self.type = type_
        self.status = status
        self.cloud_region = cloud_region
        self.selected_cloud_region = selected_cloud_region
        self.encoder_version = encoder_version
        self.selected_encoder_version = selected_encoder_version
        self.selected_encoding_mode = selected_encoding_mode
        self.name = name
        self.search = search
        self.created_at_newer_than = created_at_newer_than
        self.created_at_older_than = created_at_older_than
        self.started_at_newer_than = started_at_newer_than
        self.started_at_older_than = started_at_older_than
        self.finished_at_newer_than = finished_at_newer_than
        self.finished_at_older_than = finished_at_older_than

    @property
    def openapi_types(self):
        types = {
            'offset': 'int',
            'limit': 'int',
            'sort': 'string_types',
            'type': 'string_types',
            'status': 'string_types',
            'cloud_region': 'CloudRegion',
            'selected_cloud_region': 'CloudRegion',
            'encoder_version': 'string_types',
            'selected_encoder_version': 'string_types',
            'selected_encoding_mode': 'EncodingMode',
            'name': 'string_types',
            'search': 'string_types',
            'created_at_newer_than': 'datetime',
            'created_at_older_than': 'datetime',
            'started_at_newer_than': 'datetime',
            'started_at_older_than': 'datetime',
            'finished_at_newer_than': 'datetime',
            'finished_at_older_than': 'datetime'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'offset': 'offset',
            'limit': 'limit',
            'sort': 'sort',
            'type': 'type',
            'status': 'status',
            'cloud_region': 'cloudRegion',
            'selected_cloud_region': 'selectedCloudRegion',
            'encoder_version': 'encoderVersion',
            'selected_encoder_version': 'selectedEncoderVersion',
            'selected_encoding_mode': 'selectedEncodingMode',
            'name': 'name',
            'search': 'search',
            'created_at_newer_than': 'createdAtNewerThan',
            'created_at_older_than': 'createdAtOlderThan',
            'started_at_newer_than': 'startedAtNewerThan',
            'started_at_older_than': 'startedAtOlderThan',
            'finished_at_newer_than': 'finishedAtNewerThan',
            'finished_at_older_than': 'finishedAtOlderThan'
        }

        return attributes



from bitmovin_api_sdk.encoding.configurations.audio.mp3.mp3_api import Mp3Api
from bitmovin_api_sdk.encoding.configurations.audio.mp3.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.configurations.audio.mp3.mp3_audio_configuration_list_query_params import Mp3AudioConfigurationListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class ReuploadSettings(object):
    @poscheck_model
    def __init__(self,
                 dash_manifest_interval=None,
                 hls_manifest_interval=None,
                 muxing_init_file_interval=None):
        # type: (float, float, float) -> None

        self._dash_manifest_interval = None
        self._hls_manifest_interval = None
        self._muxing_init_file_interval = None
        self.discriminator = None

        if dash_manifest_interval is not None:
            self.dash_manifest_interval = dash_manifest_interval
        if hls_manifest_interval is not None:
            self.hls_manifest_interval = hls_manifest_interval
        if muxing_init_file_interval is not None:
            self.muxing_init_file_interval = muxing_init_file_interval

    @property
    def openapi_types(self):
        types = {
            'dash_manifest_interval': 'float',
            'hls_manifest_interval': 'float',
            'muxing_init_file_interval': 'float'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'dash_manifest_interval': 'dashManifestInterval',
            'hls_manifest_interval': 'hlsManifestInterval',
            'muxing_init_file_interval': 'muxingInitFileInterval'
        }
        return attributes

    @property
    def dash_manifest_interval(self):
        # type: () -> float
        """Gets the dash_manifest_interval of this ReuploadSettings.

        Interval in seconds to reupload the DASH manifest. Valid values are either `null` to never reupload the dash manifest or at least `30`.

        :return: The dash_manifest_interval of this ReuploadSettings.
        :rtype: float
        """
        return self._dash_manifest_interval

    @dash_manifest_interval.setter
    def dash_manifest_interval(self, dash_manifest_interval):
        # type: (float) -> None
        """Sets the dash_manifest_interval of this ReuploadSettings.

        Interval in seconds to reupload the DASH manifest. Valid values are either `null` to never reupload the dash manifest or at least `30`.

        :param dash_manifest_interval: The dash_manifest_interval of this ReuploadSettings.
        :type: float
        """

        if dash_manifest_interval is not None:
            if dash_manifest_interval is not None and dash_manifest_interval < 30:
                raise ValueError("Invalid value for `dash_manifest_interval`, must be a value greater than or equal to `30`")
            if not isinstance(dash_manifest_interval, (float, int)):
                raise TypeError("Invalid type for `dash_manifest_interval`, type has to be `float`")

        self._dash_manifest_interval = dash_manifest_interval

    @property
    def hls_manifest_interval(self):
        # type: () -> float
        """Gets the hls_manifest_interval of this ReuploadSettings.

        Interval in seconds to reupload the HLS master file. Valid values are either `0` to never reupload the hls manifest or at least `30`. This is currently not used, as the master file will always be uploaded when one of the playlist files has changed.

        :return: The hls_manifest_interval of this ReuploadSettings.
        :rtype: float
        """
        return self._hls_manifest_interval

    @hls_manifest_interval.setter
    def hls_manifest_interval(self, hls_manifest_interval):
        # type: (float) -> None
        """Sets the hls_manifest_interval of this ReuploadSettings.

        Interval in seconds to reupload the HLS master file. Valid values are either `0` to never reupload the hls manifest or at least `30`. This is currently not used, as the master file will always be uploaded when one of the playlist files has changed.

        :param hls_manifest_interval: The hls_manifest_interval of this ReuploadSettings.
        :type: float
        """

        if hls_manifest_interval is not None:
            if not isinstance(hls_manifest_interval, (float, int)):
                raise TypeError("Invalid type for `hls_manifest_interval`, type has to be `float`")

        self._hls_manifest_interval = hls_manifest_interval

    @property
    def muxing_init_file_interval(self):
        # type: () -> float
        """Gets the muxing_init_file_interval of this ReuploadSettings.

        The interval in seconds to reupload the init file for segmented muxings, e.g. fMP4, WebM. Valid values are either `null` to never reupload the init file for segmented muxings or at least `30`.

        :return: The muxing_init_file_interval of this ReuploadSettings.
        :rtype: float
        """
        return self._muxing_init_file_interval

    @muxing_init_file_interval.setter
    def muxing_init_file_interval(self, muxing_init_file_interval):
        # type: (float) -> None
        """Sets the muxing_init_file_interval of this ReuploadSettings.

        The interval in seconds to reupload the init file for segmented muxings, e.g. fMP4, WebM. Valid values are either `null` to never reupload the init file for segmented muxings or at least `30`.

        :param muxing_init_file_interval: The muxing_init_file_interval of this ReuploadSettings.
        :type: float
        """

        if muxing_init_file_interval is not None:
            if muxing_init_file_interval is not None and muxing_init_file_interval < 30:
                raise ValueError("Invalid value for `muxing_init_file_interval`, must be a value greater than or equal to `30`")
            if not isinstance(muxing_init_file_interval, (float, int)):
                raise TypeError("Invalid type for `muxing_init_file_interval`, type has to be `float`")

        self._muxing_init_file_interval = muxing_init_file_interval

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReuploadSettings):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.broadcast_ts_input_stream_configuration import BroadcastTsInputStreamConfiguration
from bitmovin_api_sdk.models.rai_unit import RaiUnit
import pprint
import six


class BroadcastTsVideoInputStreamConfiguration(BroadcastTsInputStreamConfiguration):
    @poscheck_model
    def __init__(self,
                 stream_id=None,
                 packet_identifier=None,
                 start_with_discontinuity_indicator=None,
                 align_pes=None,
                 set_rai_on_au=None,
                 insert_access_unit_delimiter_in_avc=None,
                 max_decode_delay=None):
        # type: (string_types, int, bool, bool, RaiUnit, bool, int) -> None
        super(BroadcastTsVideoInputStreamConfiguration, self).__init__(stream_id=stream_id, packet_identifier=packet_identifier, start_with_discontinuity_indicator=start_with_discontinuity_indicator, align_pes=align_pes, set_rai_on_au=set_rai_on_au)

        self._insert_access_unit_delimiter_in_avc = None
        self._max_decode_delay = None
        self.discriminator = None

        if insert_access_unit_delimiter_in_avc is not None:
            self.insert_access_unit_delimiter_in_avc = insert_access_unit_delimiter_in_avc
        if max_decode_delay is not None:
            self.max_decode_delay = max_decode_delay

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(BroadcastTsVideoInputStreamConfiguration, self), 'openapi_types'):
            types = getattr(super(BroadcastTsVideoInputStreamConfiguration, self), 'openapi_types')

        types.update({
            'insert_access_unit_delimiter_in_avc': 'bool',
            'max_decode_delay': 'int'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(BroadcastTsVideoInputStreamConfiguration, self), 'attribute_map'):
            attributes = getattr(super(BroadcastTsVideoInputStreamConfiguration, self), 'attribute_map')

        attributes.update({
            'insert_access_unit_delimiter_in_avc': 'insertAccessUnitDelimiterInAvc',
            'max_decode_delay': 'maxDecodeDelay'
        })
        return attributes

    @property
    def insert_access_unit_delimiter_in_avc(self):
        # type: () -> bool
        """Gets the insert_access_unit_delimiter_in_avc of this BroadcastTsVideoInputStreamConfiguration.

        If true, add access unit delimiters (AUD) to AVC stream if AUD is missing from input elementary stream.

        :return: The insert_access_unit_delimiter_in_avc of this BroadcastTsVideoInputStreamConfiguration.
        :rtype: bool
        """
        return self._insert_access_unit_delimiter_in_avc

    @insert_access_unit_delimiter_in_avc.setter
    def insert_access_unit_delimiter_in_avc(self, insert_access_unit_delimiter_in_avc):
        # type: (bool) -> None
        """Sets the insert_access_unit_delimiter_in_avc of this BroadcastTsVideoInputStreamConfiguration.

        If true, add access unit delimiters (AUD) to AVC stream if AUD is missing from input elementary stream.

        :param insert_access_unit_delimiter_in_avc: The insert_access_unit_delimiter_in_avc of this BroadcastTsVideoInputStreamConfiguration.
        :type: bool
        """

        if insert_access_unit_delimiter_in_avc is not None:
            if not isinstance(insert_access_unit_delimiter_in_avc, bool):
                raise TypeError("Invalid type for `insert_access_unit_delimiter_in_avc`, type has to be `bool`")

        self._insert_access_unit_delimiter_in_avc = insert_access_unit_delimiter_in_avc

    @property
    def max_decode_delay(self):
        # type: () -> int
        """Gets the max_decode_delay of this BroadcastTsVideoInputStreamConfiguration.

        Maximum Decoder Delay in 90 KHz cycles. When non-zero, the difference between the PCR and the DTS for each picture as it is inserted into the output transport stream is limited to this number of 90 KHz cycles. Values below 1000 are treated as 0 and ignored. Valid Range [0, 1000-900000]

        :return: The max_decode_delay of this BroadcastTsVideoInputStreamConfiguration.
        :rtype: int
        """
        return self._max_decode_delay

    @max_decode_delay.setter
    def max_decode_delay(self, max_decode_delay):
        # type: (int) -> None
        """Sets the max_decode_delay of this BroadcastTsVideoInputStreamConfiguration.

        Maximum Decoder Delay in 90 KHz cycles. When non-zero, the difference between the PCR and the DTS for each picture as it is inserted into the output transport stream is limited to this number of 90 KHz cycles. Values below 1000 are treated as 0 and ignored. Valid Range [0, 1000-900000]

        :param max_decode_delay: The max_decode_delay of this BroadcastTsVideoInputStreamConfiguration.
        :type: int
        """

        if max_decode_delay is not None:
            if max_decode_delay is not None and max_decode_delay > 900000:
                raise ValueError("Invalid value for `max_decode_delay`, must be a value less than or equal to `900000`")
            if max_decode_delay is not None and max_decode_delay < 1000:
                raise ValueError("Invalid value for `max_decode_delay`, must be a value greater than or equal to `1000`")
            if not isinstance(max_decode_delay, int):
                raise TypeError("Invalid type for `max_decode_delay`, type has to be `int`")

        self._max_decode_delay = max_decode_delay

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(BroadcastTsVideoInputStreamConfiguration, self), "to_dict"):
            result = super(BroadcastTsVideoInputStreamConfiguration, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BroadcastTsVideoInputStreamConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_stream_response import BitmovinStreamResponse
from bitmovin_api_sdk.models.create_bitmovin_stream_request import CreateBitmovinStreamRequest
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.update_bitmovin_stream_request import UpdateBitmovinStreamRequest
from bitmovin_api_sdk.streams.bitmovin_stream_response_list_query_params import BitmovinStreamResponseListQueryParams


class StreamsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(StreamsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, create_bitmovin_stream_request, **kwargs):
        # type: (CreateBitmovinStreamRequest, dict) -> BitmovinStreamResponse
        """Create new Stream

        :param create_bitmovin_stream_request: Create a new Stream.
        :type create_bitmovin_stream_request: CreateBitmovinStreamRequest, required
        :return: Created Stream
        :rtype: BitmovinStreamResponse
        """

        return self.api_client.post(
            '/streams',
            create_bitmovin_stream_request,
            type=BitmovinStreamResponse,
            **kwargs
        )

    def get(self, stream_id, **kwargs):
        # type: (string_types, dict) -> BitmovinStreamResponse
        """Get Stream by id

        :param stream_id: Id of the Stream.
        :type stream_id: string_types, required
        :return: Stream
        :rtype: BitmovinStreamResponse
        """

        return self.api_client.get(
            '/streams/{stream_id}',
            path_params={'stream_id': stream_id},
            type=BitmovinStreamResponse,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (BitmovinStreamResponseListQueryParams, dict) -> BitmovinStreamResponse
        """Get paginated list of Streams

        :param query_params: Query parameters
        :type query_params: BitmovinStreamResponseListQueryParams
        :return: List of all streams
        :rtype: BitmovinStreamResponse
        """

        return self.api_client.get(
            '/streams',
            query_params=query_params,
            pagination_response=True,
            type=BitmovinStreamResponse,
            **kwargs
        )

    def patch_bitmovin_streams_streams_by_stream_id(self, stream_id, update_bitmovin_stream_request, **kwargs):
        # type: (string_types, UpdateBitmovinStreamRequest, dict) -> BitmovinStreamResponse
        """Update Stream by id

        :param stream_id: Id of the Stream.
        :type stream_id: string_types, required
        :param update_bitmovin_stream_request: Stream fields to update.
        :type update_bitmovin_stream_request: UpdateBitmovinStreamRequest, required
        :return:
        :rtype: BitmovinStreamResponse
        """

        return self.api_client.patch(
            '/streams/{stream_id}',
            update_bitmovin_stream_request,
            path_params={'stream_id': stream_id},
            type=BitmovinStreamResponse,
            **kwargs
        )



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.drm import Drm
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.encodings.muxings.mp4.drm.playready.playready_api import PlayreadyApi
from bitmovin_api_sdk.encoding.encodings.muxings.mp4.drm.clearkey.clearkey_api import ClearkeyApi
from bitmovin_api_sdk.encoding.encodings.muxings.mp4.drm.widevine.widevine_api import WidevineApi
from bitmovin_api_sdk.encoding.encodings.muxings.mp4.drm.marlin.marlin_api import MarlinApi
from bitmovin_api_sdk.encoding.encodings.muxings.mp4.drm.cenc.cenc_api import CencApi
from bitmovin_api_sdk.encoding.encodings.muxings.mp4.drm.speke.speke_api import SpekeApi


class DrmApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(DrmApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.playready = PlayreadyApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.clearkey = ClearkeyApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.widevine = WidevineApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.marlin = MarlinApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.cenc = CencApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.speke = SpekeApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def get(self, encoding_id, muxing_id, drm_id, **kwargs):
        # type: (string_types, string_types, string_types, dict) -> Drm
        """DRM Details of an MP4 muxing

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param muxing_id: Id of the an MP4 muxing
        :type muxing_id: string_types, required
        :param drm_id: Id of the DRM.
        :type drm_id: string_types, required
        :return: DRM
        :rtype: Drm
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/muxings/mp4/{muxing_id}/drm/{drm_id}',
            path_params={'encoding_id': encoding_id, 'muxing_id': muxing_id, 'drm_id': drm_id},
            type=Drm,
            **kwargs
        )

    def list(self, encoding_id, muxing_id, **kwargs):
        # type: (string_types, string_types, dict) -> Drm
        """List all DRM configurations of an MP4 muxing

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param muxing_id: Id of the MP4 muxing
        :type muxing_id: string_types, required
        :return: List of DRM configurations
        :rtype: Drm
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/muxings/mp4/{muxing_id}/drm',
            path_params={'encoding_id': encoding_id, 'muxing_id': muxing_id},
            pagination_response=True,
            type=Drm,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.live_encoding_event_name import LiveEncodingEventName
import pprint
import six


class LiveEncodingStatsEventDetails(object):
    @poscheck_model
    def __init__(self,
                 event_name=None,
                 av_drift_in_seconds=None,
                 idle_duration_in_seconds=None,
                 error_message=None):
        # type: (LiveEncodingEventName, int, int, string_types) -> None

        self._event_name = None
        self._av_drift_in_seconds = None
        self._idle_duration_in_seconds = None
        self._error_message = None
        self.discriminator = None

        if event_name is not None:
            self.event_name = event_name
        if av_drift_in_seconds is not None:
            self.av_drift_in_seconds = av_drift_in_seconds
        if idle_duration_in_seconds is not None:
            self.idle_duration_in_seconds = idle_duration_in_seconds
        if error_message is not None:
            self.error_message = error_message

    @property
    def openapi_types(self):
        types = {
            'event_name': 'LiveEncodingEventName',
            'av_drift_in_seconds': 'int',
            'idle_duration_in_seconds': 'int',
            'error_message': 'string_types'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'event_name': 'eventName',
            'av_drift_in_seconds': 'avDriftInSeconds',
            'idle_duration_in_seconds': 'idleDurationInSeconds',
            'error_message': 'errorMessage'
        }
        return attributes

    @property
    def event_name(self):
        # type: () -> LiveEncodingEventName
        """Gets the event_name of this LiveEncodingStatsEventDetails.


        :return: The event_name of this LiveEncodingStatsEventDetails.
        :rtype: LiveEncodingEventName
        """
        return self._event_name

    @event_name.setter
    def event_name(self, event_name):
        # type: (LiveEncodingEventName) -> None
        """Sets the event_name of this LiveEncodingStatsEventDetails.


        :param event_name: The event_name of this LiveEncodingStatsEventDetails.
        :type: LiveEncodingEventName
        """

        if event_name is not None:
            if not isinstance(event_name, LiveEncodingEventName):
                raise TypeError("Invalid type for `event_name`, type has to be `LiveEncodingEventName`")

        self._event_name = event_name

    @property
    def av_drift_in_seconds(self):
        # type: () -> int
        """Gets the av_drift_in_seconds of this LiveEncodingStatsEventDetails.

        The Audio/Video Drift in seconds. The drift was corrected by the RESYNCING event (occurs at event: RESYNCING)

        :return: The av_drift_in_seconds of this LiveEncodingStatsEventDetails.
        :rtype: int
        """
        return self._av_drift_in_seconds

    @av_drift_in_seconds.setter
    def av_drift_in_seconds(self, av_drift_in_seconds):
        # type: (int) -> None
        """Sets the av_drift_in_seconds of this LiveEncodingStatsEventDetails.

        The Audio/Video Drift in seconds. The drift was corrected by the RESYNCING event (occurs at event: RESYNCING)

        :param av_drift_in_seconds: The av_drift_in_seconds of this LiveEncodingStatsEventDetails.
        :type: int
        """

        if av_drift_in_seconds is not None:
            if not isinstance(av_drift_in_seconds, int):
                raise TypeError("Invalid type for `av_drift_in_seconds`, type has to be `int`")

        self._av_drift_in_seconds = av_drift_in_seconds

    @property
    def idle_duration_in_seconds(self):
        # type: () -> int
        """Gets the idle_duration_in_seconds of this LiveEncodingStatsEventDetails.

        The time the stream was in idle state in seconds (occurs at event: IDLE)

        :return: The idle_duration_in_seconds of this LiveEncodingStatsEventDetails.
        :rtype: int
        """
        return self._idle_duration_in_seconds

    @idle_duration_in_seconds.setter
    def idle_duration_in_seconds(self, idle_duration_in_seconds):
        # type: (int) -> None
        """Sets the idle_duration_in_seconds of this LiveEncodingStatsEventDetails.

        The time the stream was in idle state in seconds (occurs at event: IDLE)

        :param idle_duration_in_seconds: The idle_duration_in_seconds of this LiveEncodingStatsEventDetails.
        :type: int
        """

        if idle_duration_in_seconds is not None:
            if not isinstance(idle_duration_in_seconds, int):
                raise TypeError("Invalid type for `idle_duration_in_seconds`, type has to be `int`")

        self._idle_duration_in_seconds = idle_duration_in_seconds

    @property
    def error_message(self):
        # type: () -> string_types
        """Gets the error_message of this LiveEncodingStatsEventDetails.

        An optional error message, when the event is in error state (occurs at event: ERROR)

        :return: The error_message of this LiveEncodingStatsEventDetails.
        :rtype: string_types
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        # type: (string_types) -> None
        """Sets the error_message of this LiveEncodingStatsEventDetails.

        An optional error message, when the event is in error state (occurs at event: ERROR)

        :param error_message: The error_message of this LiveEncodingStatsEventDetails.
        :type: string_types
        """

        if error_message is not None:
            if not isinstance(error_message, string_types):
                raise TypeError("Invalid type for `error_message`, type has to be `string_types`")

        self._error_message = error_message

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LiveEncodingStatsEventDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class PlayReadyEncryptionMethod(Enum):
    MPEG_CENC = "MPEG_CENC"
    PIFF_CTR = "PIFF_CTR"



from bitmovin_api_sdk.encoding.encodings.muxings.mp4.mp4_api import Mp4Api
from bitmovin_api_sdk.encoding.encodings.muxings.mp4.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.muxings.mp4.information.information_api import InformationApi
from bitmovin_api_sdk.encoding.encodings.muxings.mp4.drm.drm_api import DrmApi
from bitmovin_api_sdk.encoding.encodings.muxings.mp4.mp4_muxing_list_query_params import Mp4MuxingListQueryParams



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.keyframe import Keyframe
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.encodings.keyframes.keyframe_list_query_params import KeyframeListQueryParams


class KeyframesApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(KeyframesApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, encoding_id, keyframe, **kwargs):
        # type: (string_types, Keyframe, dict) -> Keyframe
        """Create Keyframes

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param keyframe: The Keyframes to be created
        :type keyframe: Keyframe, required
        :return: Keyframe
        :rtype: Keyframe
        """

        return self.api_client.post(
            '/encoding/encodings/{encoding_id}/keyframes',
            keyframe,
            path_params={'encoding_id': encoding_id},
            type=Keyframe,
            **kwargs
        )

    def delete(self, encoding_id, keyframe_id, **kwargs):
        # type: (string_types, string_types, dict) -> BitmovinResponse
        """Delete Keyframe

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param keyframe_id: Id of the keyframe.
        :type keyframe_id: string_types, required
        :return: Id of the keyframe
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/encodings/{encoding_id}/keyframes/{keyframe_id}',
            path_params={'encoding_id': encoding_id, 'keyframe_id': keyframe_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, encoding_id, keyframe_id, **kwargs):
        # type: (string_types, string_types, dict) -> Keyframe
        """Keyframe Details

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param keyframe_id: Id of the keyframe.
        :type keyframe_id: string_types, required
        :return: Keyframe
        :rtype: Keyframe
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/keyframes/{keyframe_id}',
            path_params={'encoding_id': encoding_id, 'keyframe_id': keyframe_id},
            type=Keyframe,
            **kwargs
        )

    def list(self, encoding_id, query_params=None, **kwargs):
        # type: (string_types, KeyframeListQueryParams, dict) -> Keyframe
        """List all Keyframes

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param query_params: Query parameters
        :type query_params: KeyframeListQueryParams
        :return: List of keyframes
        :rtype: Keyframe
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/keyframes',
            path_params={'encoding_id': encoding_id},
            query_params=query_params,
            pagination_response=True,
            type=Keyframe,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class EncodingMode(Enum):
    STANDARD = "STANDARD"
    SINGLE_PASS = "SINGLE_PASS"
    TWO_PASS = "TWO_PASS"
    THREE_PASS = "THREE_PASS"



from bitmovin_api_sdk.general.error_definitions.error_definitions_api import ErrorDefinitionsApi
from bitmovin_api_sdk.general.error_definitions.api_error_definition_list_query_params import ApiErrorDefinitionListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.auto_restart_configuration import AutoRestartConfiguration
from bitmovin_api_sdk.models.encoding_mode import EncodingMode
from bitmovin_api_sdk.models.live_auto_shutdown_configuration import LiveAutoShutdownConfiguration
from bitmovin_api_sdk.models.manifest_generator import ManifestGenerator
from bitmovin_api_sdk.models.reupload_settings import ReuploadSettings
import pprint
import six


class StartLiveEncodingRequest(object):
    @poscheck_model
    def __init__(self,
                 stream_key=None,
                 hls_manifests=None,
                 dash_manifests=None,
                 live_encoding_mode=None,
                 reupload_settings=None,
                 manifest_generator=None,
                 auto_restart_configuration=None,
                 auto_shutdown_configuration=None):
        # type: (string_types, list[LiveHlsManifest], list[LiveDashManifest], EncodingMode, ReuploadSettings, ManifestGenerator, AutoRestartConfiguration, LiveAutoShutdownConfiguration) -> None

        self._stream_key = None
        self._hls_manifests = list()
        self._dash_manifests = list()
        self._live_encoding_mode = None
        self._reupload_settings = None
        self._manifest_generator = None
        self._auto_restart_configuration = None
        self._auto_shutdown_configuration = None
        self.discriminator = None

        if stream_key is not None:
            self.stream_key = stream_key
        if hls_manifests is not None:
            self.hls_manifests = hls_manifests
        if dash_manifests is not None:
            self.dash_manifests = dash_manifests
        if live_encoding_mode is not None:
            self.live_encoding_mode = live_encoding_mode
        if reupload_settings is not None:
            self.reupload_settings = reupload_settings
        if manifest_generator is not None:
            self.manifest_generator = manifest_generator
        if auto_restart_configuration is not None:
            self.auto_restart_configuration = auto_restart_configuration
        if auto_shutdown_configuration is not None:
            self.auto_shutdown_configuration = auto_shutdown_configuration

    @property
    def openapi_types(self):
        types = {
            'stream_key': 'string_types',
            'hls_manifests': 'list[LiveHlsManifest]',
            'dash_manifests': 'list[LiveDashManifest]',
            'live_encoding_mode': 'EncodingMode',
            'reupload_settings': 'ReuploadSettings',
            'manifest_generator': 'ManifestGenerator',
            'auto_restart_configuration': 'AutoRestartConfiguration',
            'auto_shutdown_configuration': 'LiveAutoShutdownConfiguration'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'stream_key': 'streamKey',
            'hls_manifests': 'hlsManifests',
            'dash_manifests': 'dashManifests',
            'live_encoding_mode': 'liveEncodingMode',
            'reupload_settings': 'reuploadSettings',
            'manifest_generator': 'manifestGenerator',
            'auto_restart_configuration': 'autoRestartConfiguration',
            'auto_shutdown_configuration': 'autoShutdownConfiguration'
        }
        return attributes

    @property
    def stream_key(self):
        # type: () -> string_types
        """Gets the stream_key of this StartLiveEncodingRequest.

        Key for the stream. (a-zA-Z, 3-20 characters) (required)

        :return: The stream_key of this StartLiveEncodingRequest.
        :rtype: string_types
        """
        return self._stream_key

    @stream_key.setter
    def stream_key(self, stream_key):
        # type: (string_types) -> None
        """Sets the stream_key of this StartLiveEncodingRequest.

        Key for the stream. (a-zA-Z, 3-20 characters) (required)

        :param stream_key: The stream_key of this StartLiveEncodingRequest.
        :type: string_types
        """

        if stream_key is not None:
            if not isinstance(stream_key, string_types):
                raise TypeError("Invalid type for `stream_key`, type has to be `string_types`")

        self._stream_key = stream_key

    @property
    def hls_manifests(self):
        # type: () -> list[LiveHlsManifest]
        """Gets the hls_manifests of this StartLiveEncodingRequest.

        List of Hls manifests to use for this live encoding

        :return: The hls_manifests of this StartLiveEncodingRequest.
        :rtype: list[LiveHlsManifest]
        """
        return self._hls_manifests

    @hls_manifests.setter
    def hls_manifests(self, hls_manifests):
        # type: (list) -> None
        """Sets the hls_manifests of this StartLiveEncodingRequest.

        List of Hls manifests to use for this live encoding

        :param hls_manifests: The hls_manifests of this StartLiveEncodingRequest.
        :type: list[LiveHlsManifest]
        """

        if hls_manifests is not None:
            if not isinstance(hls_manifests, list):
                raise TypeError("Invalid type for `hls_manifests`, type has to be `list[LiveHlsManifest]`")

        self._hls_manifests = hls_manifests

    @property
    def dash_manifests(self):
        # type: () -> list[LiveDashManifest]
        """Gets the dash_manifests of this StartLiveEncodingRequest.

        List of Dash manifests to use for this live encoding

        :return: The dash_manifests of this StartLiveEncodingRequest.
        :rtype: list[LiveDashManifest]
        """
        return self._dash_manifests

    @dash_manifests.setter
    def dash_manifests(self, dash_manifests):
        # type: (list) -> None
        """Sets the dash_manifests of this StartLiveEncodingRequest.

        List of Dash manifests to use for this live encoding

        :param dash_manifests: The dash_manifests of this StartLiveEncodingRequest.
        :type: list[LiveDashManifest]
        """

        if dash_manifests is not None:
            if not isinstance(dash_manifests, list):
                raise TypeError("Invalid type for `dash_manifests`, type has to be `list[LiveDashManifest]`")

        self._dash_manifests = dash_manifests

    @property
    def live_encoding_mode(self):
        # type: () -> EncodingMode
        """Gets the live_encoding_mode of this StartLiveEncodingRequest.

        The pass mode of the encoding

        :return: The live_encoding_mode of this StartLiveEncodingRequest.
        :rtype: EncodingMode
        """
        return self._live_encoding_mode

    @live_encoding_mode.setter
    def live_encoding_mode(self, live_encoding_mode):
        # type: (EncodingMode) -> None
        """Sets the live_encoding_mode of this StartLiveEncodingRequest.

        The pass mode of the encoding

        :param live_encoding_mode: The live_encoding_mode of this StartLiveEncodingRequest.
        :type: EncodingMode
        """

        if live_encoding_mode is not None:
            if not isinstance(live_encoding_mode, EncodingMode):
                raise TypeError("Invalid type for `live_encoding_mode`, type has to be `EncodingMode`")

        self._live_encoding_mode = live_encoding_mode

    @property
    def reupload_settings(self):
        # type: () -> ReuploadSettings
        """Gets the reupload_settings of this StartLiveEncodingRequest.

        Reupload specific files during a live encoding. This can be helpful if an automatic life cycle policy is enabled on the output storage

        :return: The reupload_settings of this StartLiveEncodingRequest.
        :rtype: ReuploadSettings
        """
        return self._reupload_settings

    @reupload_settings.setter
    def reupload_settings(self, reupload_settings):
        # type: (ReuploadSettings) -> None
        """Sets the reupload_settings of this StartLiveEncodingRequest.

        Reupload specific files during a live encoding. This can be helpful if an automatic life cycle policy is enabled on the output storage

        :param reupload_settings: The reupload_settings of this StartLiveEncodingRequest.
        :type: ReuploadSettings
        """

        if reupload_settings is not None:
            if not isinstance(reupload_settings, ReuploadSettings):
                raise TypeError("Invalid type for `reupload_settings`, type has to be `ReuploadSettings`")

        self._reupload_settings = reupload_settings

    @property
    def manifest_generator(self):
        # type: () -> ManifestGenerator
        """Gets the manifest_generator of this StartLiveEncodingRequest.

        Sets the version of the manifest generation engine

        :return: The manifest_generator of this StartLiveEncodingRequest.
        :rtype: ManifestGenerator
        """
        return self._manifest_generator

    @manifest_generator.setter
    def manifest_generator(self, manifest_generator):
        # type: (ManifestGenerator) -> None
        """Sets the manifest_generator of this StartLiveEncodingRequest.

        Sets the version of the manifest generation engine

        :param manifest_generator: The manifest_generator of this StartLiveEncodingRequest.
        :type: ManifestGenerator
        """

        if manifest_generator is not None:
            if not isinstance(manifest_generator, ManifestGenerator):
                raise TypeError("Invalid type for `manifest_generator`, type has to be `ManifestGenerator`")

        self._manifest_generator = manifest_generator

    @property
    def auto_restart_configuration(self):
        # type: () -> AutoRestartConfiguration
        """Gets the auto_restart_configuration of this StartLiveEncodingRequest.

        Configuration for auto restarting the live encoding

        :return: The auto_restart_configuration of this StartLiveEncodingRequest.
        :rtype: AutoRestartConfiguration
        """
        return self._auto_restart_configuration

    @auto_restart_configuration.setter
    def auto_restart_configuration(self, auto_restart_configuration):
        # type: (AutoRestartConfiguration) -> None
        """Sets the auto_restart_configuration of this StartLiveEncodingRequest.

        Configuration for auto restarting the live encoding

        :param auto_restart_configuration: The auto_restart_configuration of this StartLiveEncodingRequest.
        :type: AutoRestartConfiguration
        """

        if auto_restart_configuration is not None:
            if not isinstance(auto_restart_configuration, AutoRestartConfiguration):
                raise TypeError("Invalid type for `auto_restart_configuration`, type has to be `AutoRestartConfiguration`")

        self._auto_restart_configuration = auto_restart_configuration

    @property
    def auto_shutdown_configuration(self):
        # type: () -> LiveAutoShutdownConfiguration
        """Gets the auto_shutdown_configuration of this StartLiveEncodingRequest.

        Configuration for auto shutdown of the live encoding

        :return: The auto_shutdown_configuration of this StartLiveEncodingRequest.
        :rtype: LiveAutoShutdownConfiguration
        """
        return self._auto_shutdown_configuration

    @auto_shutdown_configuration.setter
    def auto_shutdown_configuration(self, auto_shutdown_configuration):
        # type: (LiveAutoShutdownConfiguration) -> None
        """Sets the auto_shutdown_configuration of this StartLiveEncodingRequest.

        Configuration for auto shutdown of the live encoding

        :param auto_shutdown_configuration: The auto_shutdown_configuration of this StartLiveEncodingRequest.
        :type: LiveAutoShutdownConfiguration
        """

        if auto_shutdown_configuration is not None:
            if not isinstance(auto_shutdown_configuration, LiveAutoShutdownConfiguration):
                raise TypeError("Invalid type for `auto_shutdown_configuration`, type has to be `LiveAutoShutdownConfiguration`")

        self._auto_shutdown_configuration = auto_shutdown_configuration

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StartLiveEncodingRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class MotionSearch(Enum):
    DIA = "DIA"
    HEX = "HEX"
    UMH = "UMH"
    STAR = "STAR"
    FULL = "FULL"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.ts_program_clock_reference_configuration import TsProgramClockReferenceConfiguration
from bitmovin_api_sdk.models.ts_program_map_table_configuration import TsProgramMapTableConfiguration
import pprint
import six


class TsMuxingConfiguration(object):
    @poscheck_model
    def __init__(self,
                 program_number=None,
                 pmt=None,
                 pcr=None,
                 video_streams=None,
                 audio_streams=None):
        # type: (int, TsProgramMapTableConfiguration, TsProgramClockReferenceConfiguration, list[TsVideoStreamConfiguration], list[TsAudioStreamConfiguration]) -> None

        self._program_number = None
        self._pmt = None
        self._pcr = None
        self._video_streams = list()
        self._audio_streams = list()
        self.discriminator = None

        if program_number is not None:
            self.program_number = program_number
        if pmt is not None:
            self.pmt = pmt
        if pcr is not None:
            self.pcr = pcr
        if video_streams is not None:
            self.video_streams = video_streams
        if audio_streams is not None:
            self.audio_streams = audio_streams

    @property
    def openapi_types(self):
        types = {
            'program_number': 'int',
            'pmt': 'TsProgramMapTableConfiguration',
            'pcr': 'TsProgramClockReferenceConfiguration',
            'video_streams': 'list[TsVideoStreamConfiguration]',
            'audio_streams': 'list[TsAudioStreamConfiguration]'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'program_number': 'programNumber',
            'pmt': 'pmt',
            'pcr': 'pcr',
            'video_streams': 'videoStreams',
            'audio_streams': 'audioStreams'
        }
        return attributes

    @property
    def program_number(self):
        # type: () -> int
        """Gets the program_number of this TsMuxingConfiguration.

        An integer value. Value for program_number field in the MPEG Transport Stream Program Map Table (PMT). The value zero is reserved for the NIT PID entry in the PAT.

        :return: The program_number of this TsMuxingConfiguration.
        :rtype: int
        """
        return self._program_number

    @program_number.setter
    def program_number(self, program_number):
        # type: (int) -> None
        """Sets the program_number of this TsMuxingConfiguration.

        An integer value. Value for program_number field in the MPEG Transport Stream Program Map Table (PMT). The value zero is reserved for the NIT PID entry in the PAT.

        :param program_number: The program_number of this TsMuxingConfiguration.
        :type: int
        """

        if program_number is not None:
            if program_number is not None and program_number > 65535:
                raise ValueError("Invalid value for `program_number`, must be a value less than or equal to `65535`")
            if program_number is not None and program_number < 1:
                raise ValueError("Invalid value for `program_number`, must be a value greater than or equal to `1`")
            if not isinstance(program_number, int):
                raise TypeError("Invalid type for `program_number`, type has to be `int`")

        self._program_number = program_number

    @property
    def pmt(self):
        # type: () -> TsProgramMapTableConfiguration
        """Gets the pmt of this TsMuxingConfiguration.


        :return: The pmt of this TsMuxingConfiguration.
        :rtype: TsProgramMapTableConfiguration
        """
        return self._pmt

    @pmt.setter
    def pmt(self, pmt):
        # type: (TsProgramMapTableConfiguration) -> None
        """Sets the pmt of this TsMuxingConfiguration.


        :param pmt: The pmt of this TsMuxingConfiguration.
        :type: TsProgramMapTableConfiguration
        """

        if pmt is not None:
            if not isinstance(pmt, TsProgramMapTableConfiguration):
                raise TypeError("Invalid type for `pmt`, type has to be `TsProgramMapTableConfiguration`")

        self._pmt = pmt

    @property
    def pcr(self):
        # type: () -> TsProgramClockReferenceConfiguration
        """Gets the pcr of this TsMuxingConfiguration.


        :return: The pcr of this TsMuxingConfiguration.
        :rtype: TsProgramClockReferenceConfiguration
        """
        return self._pcr

    @pcr.setter
    def pcr(self, pcr):
        # type: (TsProgramClockReferenceConfiguration) -> None
        """Sets the pcr of this TsMuxingConfiguration.


        :param pcr: The pcr of this TsMuxingConfiguration.
        :type: TsProgramClockReferenceConfiguration
        """

        if pcr is not None:
            if not isinstance(pcr, TsProgramClockReferenceConfiguration):
                raise TypeError("Invalid type for `pcr`, type has to be `TsProgramClockReferenceConfiguration`")

        self._pcr = pcr

    @property
    def video_streams(self):
        # type: () -> list[TsVideoStreamConfiguration]
        """Gets the video_streams of this TsMuxingConfiguration.


        :return: The video_streams of this TsMuxingConfiguration.
        :rtype: list[TsVideoStreamConfiguration]
        """
        return self._video_streams

    @video_streams.setter
    def video_streams(self, video_streams):
        # type: (list) -> None
        """Sets the video_streams of this TsMuxingConfiguration.


        :param video_streams: The video_streams of this TsMuxingConfiguration.
        :type: list[TsVideoStreamConfiguration]
        """

        if video_streams is not None:
            if not isinstance(video_streams, list):
                raise TypeError("Invalid type for `video_streams`, type has to be `list[TsVideoStreamConfiguration]`")

        self._video_streams = video_streams

    @property
    def audio_streams(self):
        # type: () -> list[TsAudioStreamConfiguration]
        """Gets the audio_streams of this TsMuxingConfiguration.


        :return: The audio_streams of this TsMuxingConfiguration.
        :rtype: list[TsAudioStreamConfiguration]
        """
        return self._audio_streams

    @audio_streams.setter
    def audio_streams(self, audio_streams):
        # type: (list) -> None
        """Sets the audio_streams of this TsMuxingConfiguration.


        :param audio_streams: The audio_streams of this TsMuxingConfiguration.
        :type: list[TsAudioStreamConfiguration]
        """

        if audio_streams is not None:
            if not isinstance(audio_streams, list):
                raise TypeError("Invalid type for `audio_streams`, type has to be `list[TsAudioStreamConfiguration]`")

        self._audio_streams = audio_streams

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TsMuxingConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.infrastructure.prewarmed_encoder_pools.schedules.schedules_api import SchedulesApi
from bitmovin_api_sdk.encoding.infrastructure.prewarmed_encoder_pools.schedules.prewarmed_encoder_pool_schedule_list_query_params import PrewarmedEncoderPoolScheduleListQueryParams



from bitmovin_api_sdk.encoding.manifests.smooth.representations.representations_api import RepresentationsApi
from bitmovin_api_sdk.encoding.manifests.smooth.representations.mp4.mp4_api import Mp4Api



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class SimpleEncodingLiveJobInputType(Enum):
    RTMP = "RTMP"
    SRT_LISTENER = "SRT_LISTENER"
